﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using VeteransAffairs.Registries.BusinessManager;

public partial class AdminEditSettings : BasePage
{
    #region Intialize Variables
    private string _userId;
    private Reports r;
    #endregion

    protected void Page_Load(object sender, EventArgs e)
    {
        if (Helpers.checkAdminAccess())
        {
            LabelBreadCrumb.Text = "Breast Care Registry Administration > Edit Settings";
            HiddenFieldRegistryName.Value = Helpers.GetConfigEntry("Registry");
        }
        else
        {
            Response.Redirect("ErrorPage.aspx?id=100");
        }

        if (!IsPostBack)
        {
            //CRS_SP_RETRIEVE_ALL_SETTINGS
            UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;
            _userId = _user.UserId.ToString();

            r = new Reports(_userId);

            System.Data.DataTable dtSettings = r.GetAllSettings(_user.RegistryId);

            GridViewSettings.DataSource = dtSettings;
            GridViewSettings.DataBind();

            LabelError.Text = "";
            LabelError.Visible = false;
        }
    }

    public override string MenuItemName()
    {
        return "List Users";
    }

    public override string AppObjectCode()
    {
        return "BCCCR ADMIN LIST USERS";
    }

    public override string TopMenuName()
    {
        return "Administration";
    }

    protected void ButtonClear_Click(object sender, EventArgs e)
    {
        //this.TextBoxSearchCriteria.Text = "";
    }
    protected void GridViewSettings_RowEditing(object sender, GridViewEditEventArgs e)
    {
        try
        {
            GridViewSettings.EditIndex = (int)GridViewSettings.DataKeys[e.NewEditIndex].Value;

            this.PopulateData((int)GridViewSettings.DataKeys[e.NewEditIndex].Value);
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(ex.Message);
        }
    }

    private void PopulateData(int settingId)
    {
        //CRS_SP_RETRIEVE_ALL_SETTINGS
        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;
        _userId = _user.UserId.ToString();

        r = new Reports(_userId);

        System.Data.DataTable dtSettings = r.GetSettingForUpdate(_user.RegistryId, settingId);

        if (dtSettings != null && dtSettings.Rows.Count > 0)
        {
            PanelSettings.Visible = false;
            PanelSettingInformation.Visible = true;

            TextBoxName.Text = dtSettings.Rows[0][1].ToString();
            TextBoxValue.Text = dtSettings.Rows[0][2].ToString();
            TextBoxDescription.Text = dtSettings.Rows[0][3].ToString();
            TextBoxComment.Text = dtSettings.Rows[0][4].ToString();
            HiddenFieldSettingId.Value = dtSettings.Rows[0][0].ToString();
        }
        else
        {
            Logging.WriteLogToFile(_user.UserId.ToString(), "Could not find setting for setting: " + settingId.ToString());

            LabelError.Text = "Error loading Setting";
            LabelError.Visible = true;
        }
    }

    protected void ButtonSave_Click(object sender, EventArgs e)
    {
        string comment = "";
        string value = "";
        string description = "";
        
        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;
        _userId = _user.UserId.ToString();

        r = new Reports(_userId);

        int settingId = Convert.ToInt32(HiddenFieldSettingId.Value);

        value = HttpUtility.HtmlEncode(TextBoxValue.Text);
        description = HttpUtility.HtmlEncode(TextBoxDescription.Text);
        comment = HttpUtility.HtmlEncode(TextBoxComment.Text);


        var numRows = r.SetSettingForUpdate(_user.RegistryId, settingId,
            value, description, comment);

        if (Convert.ToInt32(numRows) != 1)
        {
            Logging.WriteLogToFile("Did not save setting: " + settingId.ToString());
            LabelError.Text = "Did not save setting: " + settingId.ToString();
            LabelError.Visible = true;
        }
        else
        {
            LabelError.Text = "Save successful";
            LabelError.Visible = true;
        }

    }
    protected void ButtonClose_Click(object sender, EventArgs e)
    {
        PanelSettingInformation.Visible = false;
        PanelSettings.Visible = true;

        //CRS_SP_RETRIEVE_ALL_SETTINGS
        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;
        _userId = _user.UserId.ToString();

        r = new Reports(_userId);

        System.Data.DataTable dtSettings = r.GetAllSettings(_user.RegistryId);

        GridViewSettings.DataSource = dtSettings;
        GridViewSettings.DataBind();

        LabelError.Text = "";
        LabelError.Visible = false;
    }
    protected void GridViewSettings_RowDataBound(object sender, GridViewRowEventArgs e)
    {
        if (e.Row.RowType == DataControlRowType.DataRow)
        {
            e.Row.Cells[1].Text = HttpUtility.HtmlDecode(e.Row.Cells[1].Text);
            e.Row.Cells[2].Text = HttpUtility.HtmlDecode(e.Row.Cells[2].Text);
            e.Row.Cells[3].Text = HttpUtility.HtmlDecode(e.Row.Cells[3].Text);
        }
    }
}
