﻿using System.Data;
using Telerik.Web.UI;
using System;

public class Reports
{
    //stored proc const
    private const string GET_USER_FAC = "bcccr.usp_Get_Fac_by_UserId";
    private const string GET_VISNS = "bcccr.usp_Get_VISNs";
    private const string GET_FACS = "bcccr.usp_Get_Facs";
    private const string GET_PACS = "bcccr.usp_Get_PACs";
    private const string GET_FAC_BY_VISN = "bcccr.usp_Get_Fac_by_VISNId";
    private const string GET_PAC_BY_FAC = "bcccr_sp_Get_PAC_by_FacId";
    private const string GET_PATIENT_RACES = "bcccr.usp_Get_Race";
    private const string GET_DISTINCT_PATIENT_RACES = "bcccr.usp_Get_Distinct_Patient_Races";
    private const string GET_PATIENT_GENDER = "bcccr.usp_Get_Gender";
    private const string GET_DIVS_BY_DIV_ID = "bcccr.usp_Get_Children_by_DivId";
    private const string GET_SETTING = "CRS_SP_RETRIEVE_SETTING";
    private const string GET_ALL_SETTINGS = "CRS_SP_RETRIEVE_ALL_SETTINGS";
    private const string GET_SETTING_FOR_UPDATE = "CRS_SP_RETRIEVE_SETTING_FOR_UPDATE";
    private const string SET_SETTING_FOR_UPDATE = "CRS_SP_UPDATE_SETTING";

    private string _userId;

    private DataTable _dtFac = null;
    private DataTable _dtRaces = null;
    private DataTable _dtGenders = null;

    public DataTable dtFac { get { return _dtFac; } }
    public DataTable dtRace { get { return _dtRaces; } }
    public DataTable dtGender { get { return _dtGenders; } }

    public Reports(string userId)
    {
        _userId = userId;
    }

    //***Populate Listboxes***//
    //Aggregate
    public DataTable GetVISNs()
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_VISNS, new object[] { });
    }

    public DataTable GetDivsByDivId(string divId)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_DIVS_BY_DIV_ID, new object[] { divId });
    }

    public DataTable GetFacs()
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_FACS, new object[] { });
    }

    public DataTable GetPACs()
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_PACS, new object[] { });
    }

    public DataTable GetFacsByVISNList(string visnList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_FAC_BY_VISN, new object[] { visnList });
    }

    public DataTable GetPACByFacList(string facList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_PAC_BY_FAC, new object[] { facList });
    }

    public Object GetSetting(string settingName, int registryId)
    {
        //return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_SETTING, new object[] { settingName, registryId });
        return SqlProvider.ExecuteScalar(Globals.GetConnectionName, GET_SETTING, new object[] { settingName, registryId });
    }

    public DataTable GetAllSettings(int registryId)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_SETTINGS, new object[] { registryId });
    }

    public DataTable GetSettingForUpdate(int registryId, int settingId)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_SETTING_FOR_UPDATE, new object[] { registryId, settingId });
    }

    public Object SetSettingForUpdate(int registryId, int settingId, string value, string description, string comment)
    {
        return SqlProvider.ExecuteScalar(Globals.GetConnectionName, SET_SETTING_FOR_UPDATE, new object[] { registryId, settingId, value, description, comment });
    }


    //Patient Data
    public bool GetFacilitiesByUserId()
    {
        _dtFac = SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_USER_FAC, new object[] { _userId });
        if ((_dtFac != null) && (_dtFac.IsInitialized) && (_userId.Length > 0))
        {
            return true;
        }
        else
            return false;
    }

    //Race Data
    public bool GetPatientRaces()
    {
        _dtRaces = SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_PATIENT_RACES, new object[] { });
        if ((_dtRaces != null) && (_dtRaces.IsInitialized))
        {
            return true;
        }
        else
            return false;
    }

    /// <summary>
    /// Returns a list of distinct patient races from the BCR_ALL table.
    /// </summary>
    /// <returns></returns>
    public DataTable GetDistinctPatientRaces()
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_DISTINCT_PATIENT_RACES, new object[] { });
    }


    //Gender Data
    public bool GetPatientGenders()
    {
        _dtGenders = SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_PATIENT_GENDER, new object[] { });
        if ((_dtGenders != null) && (_dtGenders.IsInitialized))
        {
            return true;
        }
        else
            return false;
    }

    //BiRad Data
    //public bool GetPatientBirads()
    //{
    //    _dtBiRad = SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_PATIENT_BIRAD, new object[] { });
    //    if ((_dtBiRad != null) && (_dtBiRad.IsInitialized))
    //    {
    //        return true;
    //    }
    //    else
    //        return false;
    //}


    //Gets comma delimited string of VISNs, FACs or PACs
    public string GetCommaDelimitedList(RadListBox rlb)
    {
        string CheckedList = String.Empty;

        foreach (RadListBoxItem item in rlb.Items)
        {
            if (item.Checked)
            {
                CheckedList += item.Value + ",";
            }
            //make sure list is populated
            if (CheckedList.Length > 0)
            {
                CheckedList = CheckedList.Trim().Substring(0, CheckedList.Length - 1);
            }
        }

        return CheckedList;
    }
    //***
}

public class PatientData
{
    //template 
    private const string GET_REPORT_NAME = "bcccr.usp_RptPD_Report_Name";
    //***

    private const string GET_ORDERED_PENDING_PD = "bcccr.usp_RptPD_Ordered_Pending";
    private const string GET_ALL_MAM_WITH_BIRAD_PD = "bcccr.usp_RptPD_All_Mammo_By_Birad_By_Date";
    private const string GET_ALL_MAM_BY_DIAG_PD = "bcccr.usp_RptPD_All_Mammogram_By_Diagnosis";
    private const string GET_ALL_MAM_DUE_PD = "bcccr.usp_RptPD_All_Mammo_Due";
    private const string GET_BREAST_BIOPSIES_PD = "bcccr.usp_RptPD_Breast_Biopsies";
    private const string GET_BREAST_SURGERIES_PD = "bcccr.usp_RptPD_Breast_Surgery";
    private const string GET_BREAST_CANCER_PD = "bcccr.usp_RptPD_Breast_Cancer";
    private const string GET_ALL_MAM_FOLLOW_UP_PD = "bcccr.usp_RptPD_All_Mammo_followup";
    private const string GET_ALL_ABNORMAL_MAM_PD = "bcccr.usp_RptPD_All_Abnormal_Mammo_Surgeries_Bios_By_Birad";
    private const string GET_ALL_MAM_ICD_PD = "bcccr.usp_RptPD_All_Mammogram_icd";


    // New
    private const string GET_ALL_MAMMO_ABNORMAL_MAMMO_PD = "BCCCR.usp_Std_Rpt_GetMammogramsByDateAndFacId";
    private const string GET_MAMMO_DUE_ORDERED_PENDING_PD = "BCCCR.usp_Std_Rpt_GetMammoDueAndOrderedPendingByFacId";
    private const string GET_MAMMO_DUE_PD = "BCCCR.usp_Std_Rpt_GetMammoDueByDateRangeAndFacId";
    private const string GET_ORDERED_PENDING_RPT_PD = "BCCCR.usp_Std_Rpt_GetOrderedPendingByDateRangeAndFacId";
    private const string GET_BREAST_BIOPSIES_SURGERIES_PD = "BCCCR.usp_Std_Rpt_GetBiopAndSurgByDateAndFacId";
    private const string GET_STD_BREAST_CANCER_PD = "BCCCR.usp_Std_Rpt_GetBreastCancerByDateAndFacId";
    private const string GET_PATIENT_DETAILS = "BCCCR.usp_GetPatientDetails";

    private DataTable _dtRpt = null;
    public DataTable dtRptPD { get { return _dtRpt; } }

    public PatientData()
    {
    }

    //template
    public DataTable GetReportName(string facList, string pacList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_REPORT_NAME, new object[] { facList });
    }
    //***
    //Patient Data Reports

    public DataTable GetOrderedPending(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ORDERED_PENDING_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetAllMamDue(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_DUE_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetAllMamWithBiRad(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_WITH_BIRAD_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetMamByDiag(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_BY_DIAG_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetAllMamWithResults(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_ICD_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetAllMamWithFollowUp(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_FOLLOW_UP_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetAllAbnormalMam(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_ABNORMAL_MAM_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetAllMamsICD(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_ICD_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetBreastBiopsies(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_BIOPSIES_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetBreastSurgeries(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_SURGERIES_PD, new object[] { facId, fromDate, toDate });
    }
    public DataTable GetBreastCancer(string facId, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_CANCER_PD, new object[] { facId, fromDate, toDate });
    }


    #region NEW METHODS - DME contract

    /// <summary>
    /// GetAllMammogramsAbnormalMammo: Calls the BCCCR.usp_Std_Rpt_GetMammogramsByDateAndFacId stored procedure to return a data table of mammogram-related data.
    /// </summary>
    /// <param name="facId"></param>
    /// <param name="startDate"></param>
    /// <param name="endDate"></param>
    /// <param name="showLatest"></param>
    /// <param name="biradList"></param>
    /// <param name="patName"></param>
    /// <param name="gender"></param>
    /// <param name="providerName"></param>
    /// <returns></returns>
    public DataTable GetAllMammogramsAbnormalMammo(string facId, string startDate, string endDate, int showLatest, string biradList, string ageRestriction, string patName, string gender, string providerName, string race)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAMMO_ABNORMAL_MAMMO_PD, new object[] { facId, startDate, endDate, showLatest, biradList, ageRestriction, patName, gender, providerName, race });
    }

    /// <summary>
    /// GetMammogramsDue: Calls the BCCCR.usp_Std_Rpt_GetMammoDueByDateRangeAndFacId stored procedure to return a data table of mammogram-related data.
    /// </summary>
    /// <param name="facId"></param>
    /// <param name="startDate"></param>
    /// <param name="endDate"></param>
    /// <param name="ageRestriction"></param>
    /// <param name="patName"></param>
    /// <param name="gender"></param>
    /// <param name="providerName"></param>
    /// <returns></returns>
    public DataTable GetMammogramsDue(string facId, string startDate, string endDate, string ageRestriction, string patName, string gender, string providerName, string mammotypeString, string race)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_MAMMO_DUE_PD, new object[] { facId, startDate, endDate, ageRestriction, patName, gender, providerName, mammotypeString, race });
    }

    /// <summary>
    /// GetOrderedPending: Calls the BCCCR.usp_Std_Rpt_GetOrderedPendingByDateRangeAndFacId stored procedure to return a data table of mammogram-related data.
    /// </summary>
    /// <param name="facId"></param>
    /// <param name="startDate"></param>
    /// <param name="endDate"></param>
    /// <param name="showLatest"></param>
    /// <param name="ageRestriction"></param>
    /// <param name="patName"></param>
    /// <param name="gender"></param>
    /// <param name="providerName"></param>
    /// <param name="mammotypeString"></param>
    /// <returns></returns>
    public DataTable GetOrderedPending(string facId, string startDate, string endDate, int showLatest, string ageRestriction, string patName, string gender, string providerName, string mammotypeString, string race)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ORDERED_PENDING_RPT_PD, new object[] { facId, startDate, endDate, showLatest, ageRestriction, patName, gender, providerName, mammotypeString, race });
    }

    /// <summary>
    /// GetAllMammogramsAbnormalMammo: Calls the BCCCR.usp_Std_Rpt_GetMammoDueAndOrderedPendingByFacId stored procedure to return a data table of mammograms due and ordered pending data.
    /// </summary>
    /// <param name="facId"></param>
    /// <returns></returns>
    public DataTable GetMammogramsDueOrderedPending(string facId)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_MAMMO_DUE_ORDERED_PENDING_PD, new object[] { facId });
    }

    /// <summary>
    /// GetBreastBiopsiesSurgeries: Calls the  stored procedure to return a data table of biopsy and surgery-related data.
    /// </summary>
    /// <param name="facId"></param>
    /// <returns></returns>
    public DataTable GetBreastBiopsiesSurgeries(string sta3n, string startDate, string endDate, string patName, string ageRestriction, string gender, string searchReportType, string providerName, string race)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_BIOPSIES_SURGERIES_PD, new object[] { sta3n, startDate, endDate, patName, ageRestriction, gender, searchReportType, providerName, race });
    }

    /// <summary>
    /// GetBreastBiopsiesSurgeries: Calls the  stored procedure to return a data table of biopsy and surgery-related data.
    /// </summary>
    /// <param name="facId"></param>
    /// <returns></returns>
    public DataTable GetBreastCancerStdRpt(string facId, string startDate, string endDate, string patName, string gender, string providerName, string race)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_STD_BREAST_CANCER_PD, new object[] { facId, startDate, endDate, patName, gender, providerName, race });
    }

    /// <summary>
    /// GetPatientDetails: Returns a Dataset for Patient Details-related data.
    /// </summary>
    /// <param name="patientId"></param>
    /// <returns></returns>
    public DataSet GetPatientDetails(string patientId)
    {
        return SqlProvider.ExecuteSPDataset(Globals.GetConnectionName, GET_PATIENT_DETAILS, new object[] { patientId });
    }

    #endregion
    //***
}

public class AdHocR
{
    //template 
    private const string GET_REPORT_NAME = "bcccr.usp_RptAdHoc_Report_Name";
    //***

    private const string GET_AD_HOC = "bcccr.usp_RptAH_Main";
    private const string GET_AD_HOC_ALL_ABNORMAL = "bcccr.usp_RptAH_All_Abnormal_Mammo_Surgeries_Bios_By_Birad";
    private const string GET_AD_HOC_ALL_MAMMOGRAMS = "bcccr.usp_RptAH_All_Mammo_By_Birad_By_Date";
    private const string GET_AD_HOC_ALL_MAMMOGRAMS_DUE = "bcccr.usp_RptAH_All_Mammo_due";
    private const string GET_AD_HOC_BREAST_BIOPSY = "bcccr.usp_RptAH_Breast_Biopsies";
    private const string GET_AD_HOC_BREAST_CANCER = "bcccr.usp_RptAH_Breast_Cancer";
    private const string GET_AD_HOC_BREAST_SURGERY = "bcccr.usp_RptAH_Breast_Surgery";
    private const string GET_AD_HOC_ORDERED_PENDING = "bcccr.usp_RptAH_Ordered_Pending";
    private const string GET_AD_HOC_MAMMOGRAM_WITH_FOLLOWUP = "bcccr.usp_RptAH_Mammogram_With_Followup";

    private DataTable _dtRpt = null;
    public DataTable dtRptPD { get { return _dtRpt; } }

    public AdHocR()
    {
    }

    //template
    public DataTable GetReportName(string facList, string pacList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_REPORT_NAME, new object[] { facList });
    }
    //***
    //AdHoc Reports

    public DataTable GetAdHoc(int facId, string ageList, string raceList, string genderList, string biradList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_AD_HOC, new object[] { facId, ageList, raceList, genderList, biradList });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocAllAbnormalMammograms(string patientId)
    {
        //return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_AD_HOC_ALL_ABNORMAL, new object[] { patientId });
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_ALL_ABNORMAL, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocAllMammograms(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_ALL_MAMMOGRAMS, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocAllMammogramsDue(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_ALL_MAMMOGRAMS_DUE, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocBreastBiopsy(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_BREAST_BIOPSY, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocBreastCancer(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_BREAST_CANCER, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocBreastSurgery(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_BREAST_SURGERY, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocOrderedPending(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_ORDERED_PENDING, new object[] { patientId });
    }

    public System.Data.SqlClient.SqlDataReader GetAdHocMammogramWithFollowup(string patientId)
    {
        return SqlProvider.ExecuteSPReader(Globals.GetConnectionName, GET_AD_HOC_MAMMOGRAM_WITH_FOLLOWUP, new object[] { patientId });
    }

    //public DataTable GetAdHocAllAbnormalMammograms(string patientId)
    //{
    //    //return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_AD_HOC_ALL_ABNORMAL, new object[] { patientId });
    //    return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_AD_HOC_ALL_ABNORMAL, new object[] { patientId });
    //}
}

public class Aggregate
{
    //template 
    private const string GET_REPORT_NAME = "bcccr.usp_RptAGG_Report_Name";
    //***
    private const string GET_ORDERED_PENDING_BIRAD_AGG = "bcccr.usp_RptAGG_Ordered_Pending_By_Birad";

    private const string GET_ALL_ABNORMAL_MAM_AGG = "[BCCCR].[usp_RptAgg_all_abnormal_mam_biop_surg]";
    private const string GET_ALL_MAM_AGG = "bcccr.usp_RptAgg_All_Mammo";
    private const string GET_ALL_MAM_DUE_AGG = "bcccr.usp_RptAgg_All_Mammo_due";
    private const string GET_ALL_MAM_FOLLOW_UP_AGG = "bcccr.usp_RptAgg_All_Mammo_followup";
    private const string GET_ALL_MAM_BY_DIAG_AGG = "bcccr.usp_RptAgg_All_Mammo_icd";
    private const string GET_BREAST_BIOPSIES_AGG = "bcccr.usp_RptAgg_all_biopsies";
    private const string GET_BREAST_SURGERIES_AGG = "bcccr.usp_RptAgg_All_Surgeries";
    private const string GET_BREAST_CANCER_AGG = "bcccr.usp_RptAgg_All_Breast_Cancer";

    // New
    private const string GET_ALL_MAMMO_BIRAD_DIST_AGG = "BCCCR.usp_Agg_Rpt_GetMammoCountBiRADDistribution";
    private const string GET_MAMMOGRAM_COMPLIANCE_BY_VISN_AGG = "BCCCR.usp_Agg_Rpt_GetMammoScreeningCompByVISN";
    private const string GET_BREAST_CANCER_BY_VISN_AGG = "BCCCR.usp_Agg_Rpt_GetBreastCancerByVISN";
    private const string GET_BREAST_CANCER_BY_FAC_ID_AGG = "BCCCR.usp_Agg_Rpt_GetBreastCancerByFacId";


    private DataTable _dtRpt = null;
    public DataTable dtRptAGG { get { return _dtRpt; } }

    public Aggregate()
    {
    }

    //template
    public DataTable GetReportName(string facList, string pacList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_REPORT_NAME, new object[] { facList });
    }
    //***

    public DataTable GetAllMam(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate, string ageList, string raceList, string genderList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate, ageList, raceList, genderList });
    }

    public DataTable GetAllMamDue(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate, string ageList, string raceList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_DUE_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate, ageList, raceList });
    }

    public DataTable GetAllMamFollowUp(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate, string ageList, string raceList, string genderList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_FOLLOW_UP_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate, ageList, raceList, genderList });
    }

    public DataTable GetAllMamByDiag(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAM_BY_DIAG_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate });
    }

    public DataTable GetBreastBiopsiesAgg(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_BIOPSIES_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate });
    }

    public DataTable GetBreastSurgeriesAgg(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_SURGERIES_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate });
    }

    public DataTable GetBreastCancerAgg(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate, string ageList, string genderList, string raceList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_CANCER_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate, ageList, raceList, genderList });
    }

    public DataTable GetAbnormalAgg(bool all, bool nat, string visnList, string facList, string pacList, string fromDate, string toDate, string ageList, string raceList, string genderList, string biradList)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_ABNORMAL_MAM_AGG, new object[] { all, nat, visnList, facList, pacList, fromDate, toDate, ageList, raceList, genderList, biradList });
    }

    /// <summary>
    /// GetMammogramsWithBiRadDistrAgg: Calls the BCCCR.usp_Agg_Rpt_GetMammoCountBiRADDistribution stored procedure to return the aggregate report for the passed parameters.
    /// </summary>
    /// <param name="startDate"></param>
    /// <param name="endDate"></param>
    /// <returns></returns>
    public DataTable GetMammogramsWithBiRadDistrAgg(string visnFacilityId, string startDate, string endDate) {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_ALL_MAMMO_BIRAD_DIST_AGG, new object[] { visnFacilityId, startDate, endDate });
    }

    /// <summary>
    /// GetMammogramComplianceByVISNAgg: Calls the BCCCR.usp_Agg_Rpt_GetMammoScreeningCompByVISN stored procedure to return the aggregate report for the passed parameters.
    /// </summary>
    /// <param name="visnFacilityId"></param>
    /// <param name="startDate"></param>
    /// <param name="endDate"></param>
    /// <returns></returns>
    public DataTable GetMammogramComplianceByVISNAgg(string visnFacilityId, string startDate, string endDate)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_MAMMOGRAM_COMPLIANCE_BY_VISN_AGG, new object[] { visnFacilityId });
    }

    /// <summary>
    /// GetBreastCancerByVISNAgg: Calls the BCCCR.usp_Agg_Rpt_GetBreastCancerByVISN stored procedure to return the aggregate report for the passed parameters.
    /// </summary>
    /// <param name="visnFacilityId"></param>
    /// <returns></returns>
    public DataTable GetBreastCancerByVISNAgg(string visnFacilityId)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_CANCER_BY_VISN_AGG, new object[] { visnFacilityId });
    }

    /// <summary>
    /// GetBreastCancerByFacilityIdAgg: Calls the BCCCR.usp_Agg_Rpt_GetBreastCancerByFacId stored procedure to return the aggregate report for the passed parameters.
    /// </summary>
    /// <param name="facilityId"></param>
    /// <returns></returns>
    public DataTable GetBreastCancerByFacilityIdAgg(string facilityId)
    {
        return SqlProvider.ExecuteSPDataTable(Globals.GetConnectionName, GET_BREAST_CANCER_BY_FAC_ID_AGG, new object[] { facilityId });
    }
    
}