﻿using System;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;

public partial class BiRad : BasePage
{
    #region Intialize Variables
    private string _userId;
    bool isExport = false;
    #endregion

    #region Page Events
    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "Abnormal Mammograms Aggregate";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;

        _userId = _user.UserId.ToString();

        try
        {

            #region Set Date Params
            toDate.MaxDate = DateTime.Today;
            fromDate.MaxDate = DateTime.Today;
            #endregion

            if (!IsPostBack)
            {
                FillDivisionTree();
                FillFilters();

                //set date
                fromDate.SelectedDate = DateTime.Today.AddYears(-1);
                toDate.SelectedDate = DateTime.Today;
            }

            GridFilterMenu menu = rgAggregateData.FilterMenu;
            int i = 0;

            //loop through filter menu
            while (i < menu.Items.Count)
            {
                try
                {
                    //add tooltip and access key for 508
                    if (menu.Items[i] != null)
                    {
                        menu.Items[i].ToolTip = menu.Items[i].Text;
                        //symbols
                        int asciiChar = i + 41;
                        char charValue = Convert.ToChar(asciiChar);
                        menu.Items[i].AccessKey = charValue.ToString();
                    }
                }
                catch (Exception ex)
                {
                    Logging.WriteLogToFile(_userId, ex);
                }

                i += 1;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Private Methods

    private void CreateReport()
    {
        bool all = false;
        bool nat = false;
        string level1 = null;
        string level2 = null;
        string level3 = null;
        string level1Desc = "";
        string level2Desc = "";
        string level3Desc = "";

        try
        {

            foreach (RadTreeNode rtn in rtvDivision.CheckedNodes)
            {
                switch (rtn.Level)
                {
                    case 0:
                        all = true;
                        break;
                    case 1:
                        level1 += rtn.Value + ",";
                        level1Desc += rtn.Text + ",";
                        break;
                    case 2:
                        level2 += rtn.Value + ",";
                        level2Desc += rtn.Text + ",";
                        break;
                    case 3:
                        level3 += rtn.Value + ",";
                        level3Desc += rtn.Text + ",";
                        break;
                }
            }
            if (level1Desc != "")
            {
                level1Desc = level1Desc.Trim().Substring(0, level1Desc.Length - 1);
            }

            if (level2Desc != "")
            {
                level2Desc = level2Desc.Trim().Substring(0, level2Desc.Length - 1);
            }

            if (level3Desc != "")
            {
                level3Desc = level3Desc.Trim().Substring(0, level3Desc.Length - 1);
            }

            bool showFilterlabel = false;
            string visnList = null;
            string facList = null;
            string pacList = null;
            string ageTextList = "";
            string genderTextList = "";
            string raceTextList = "";
            string biradTextList = "";

            if (level1 != null)
            {
                string[] l1 = level1.Split(',');

                foreach (string s in l1)
                {
                    if (s == "NAT")
                    {
                        nat = true;
                    }
                }
                //remove NAT from VISN list
                visnList = level1.Trim().Substring(0, level1.Length - 1).Replace("NAT,", "").Replace("NAT", "");
            }
            if (level2 != null)
            {
                facList = level2.Trim().Substring(0, level2.Length - 1);
            }
            if (level3 != null)
            {
                pacList = level3.Trim().Substring(0, level3.Length - 1);
            }

            string ageList = null;
            foreach (RadListBoxItem item in rlbAge.Items)
            {
                if (item.Checked == true)
                {
                    if (item.Value != "All")
                    {
                        ageList += item.Value + ",";
                        ageTextList += item.Text + ",";
                    }
                }
            }
            if (ageList != null)
            {
                ageList = ageList.Trim().Substring(0, ageList.Length - 1);
            }
            if (ageTextList != "")
            {
                ageTextList = ageTextList.Trim().Substring(0, ageTextList.Length - 1);
            }
            string raceList = null;
            foreach (RadListBoxItem item in rlbRace.Items)
            {
                if (item.Checked == true)
                {
                    if (item.Value != "All")
                    {
                        raceList += item.Value + ",";
                        raceTextList += item.Text + ",";
                    }
                }
            }
            if (raceList != null)
            {
                raceList = raceList.Trim().Substring(0, raceList.Length - 1);
            }
            if (raceTextList != "")
            {
                raceTextList = raceTextList.Trim().Substring(0, raceTextList.Length - 1);
            }

            string genderList = null;
            foreach (RadListBoxItem item in rlbGender.Items)
            {
                if (item.Checked == true)
                {
                    if (item.Value != "All")
                    {
                        genderList += item.Value + ",";
                        genderTextList += item.Text + ",";
                    }
                }
            }
            if (genderList != null)
            {
                genderList = genderList.Trim().Substring(0, genderList.Length - 1);
            }
            if (genderTextList != "")
            {
                genderTextList = genderTextList.Trim().Substring(0, genderTextList.Length - 1);
            }

            string biradList = null;
            foreach (RadListBoxItem item in rlbBirads.Items)
            {
                if (item.Checked == true)
                {
                    if (item.Value != "All")
                    {
                        biradList += item.Value + ",";
                        biradTextList += item.Text + ",";
                    }
                }
            }
            if (biradList != null)
            {
                biradList = biradList.Trim().Substring(0, biradList.Length - 1);
            }
            if (biradTextList != "")
            {
                biradTextList = biradTextList.Trim().Substring(0, biradTextList.Length - 1);
            }

            Aggregate agg = new Aggregate();

            #region Build Filter Label
            System.Text.StringBuilder MyStringBuilder = new System.Text.StringBuilder("<span STYLE='font-style: bold; color:black'>Selected Filter(s): </span>");

            if (level1Desc != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>VISN(s): </span>");
                MyStringBuilder.Append(level1Desc);
                showFilterlabel = true;
            }

            if (level2Desc != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>Facility(s): </span>");
                MyStringBuilder.Append(level2Desc);
                showFilterlabel = true;
            }

            if (level3Desc != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>PAC(s): </span>");
                MyStringBuilder.Append(level3Desc);
                showFilterlabel = true;
            }

            if (fromDate.DbSelectedDate != null)
            {
                if (fromDate.DbSelectedDate.ToString().Length > 0)
                {
                    MyStringBuilder.Append("<br>");
                    MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>Date Range: </span>");
                    MyStringBuilder.Append(fromDate.DbSelectedDate.ToString().Replace("12:00:00 AM", ""));
                    showFilterlabel = true;
                }
            }

            if (toDate.DbSelectedDate != null)
            {
                if (toDate.DbSelectedDate.ToString().Length > 0)
                {
                    MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'> to </span>");
                    MyStringBuilder.Append(toDate.DbSelectedDate.ToString().Replace("12:00:00 AM", ""));
                    showFilterlabel = true;
                }
            }

            if (biradTextList != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>Birad(s): </span>");
                MyStringBuilder.Append(biradTextList);
                showFilterlabel = true;
            }

            if (ageTextList != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>Age Range: </span>");
                MyStringBuilder.Append(ageTextList);
                showFilterlabel = true;
            }

            if (genderTextList != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>Gender(s): </span>");
                MyStringBuilder.Append("Gender(s): ");
                MyStringBuilder.Append(genderTextList);
                showFilterlabel = true;
            }

            if (raceTextList != "")
            {
                MyStringBuilder.Append("<br>");
                MyStringBuilder.Append("<span STYLE='font-style: bold; color:black'>Race(s): </span>");
                MyStringBuilder.Append(raceTextList);
                showFilterlabel = true;
            }

            if (showFilterlabel == true)
                lblFilterSelected.Text = MyStringBuilder.ToString();

            #endregion

            DataTable dt = agg.GetAbnormalAgg(all, nat, visnList, facList, pacList, fromDate.DbSelectedDate.ToString(), toDate.DbSelectedDate.ToString(), ageList, raceList, genderList, biradList);
            //DataTable dt = GetMockUpData();
            //LoadCharts(dt);

            if (dt != null && rtvDivision.CheckedNodes.Count > 0)
            {
                rgAggregateData.DataSource = dt;

                if (rtvDivision.CheckedNodes.Count <= 5 && all == false)
                {
                    rcBar.Visible = true;
                    LoadCharts(dt);
                }
                else
                {
                    rcBar.Visible = false;
                }
            }
            else
            {
                rgAggregateData.DataSource = "";
                //rcBar.Visible = false;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void FillFilters()
    {
        try
        {
            //instatiate reports
            Reports r = new Reports(_userId);

            //get the user's facilities and populate listbox
            if (r.GetPatientRaces())
            {
                //clear existing items
                rlbRace.Items.Clear();
                rlbRace.DataSource = r.dtRace;
                rlbRace.DataTextField = "name";
                rlbRace.DataValueField = "id";
                rlbRace.DataBind();
                RadListBoxItem item = new RadListBoxItem("All", "All");
                rlbRace.Items.Insert(0, item);
            }

            if (r.GetPatientGenders())
            {
                //clear existing items
                rlbGender.Items.Clear();
                rlbGender.DataSource = r.dtGender;
                rlbGender.DataTextField = "description_text";
                rlbGender.DataValueField = "id";
                rlbGender.DataBind();
                RadListBoxItem item = new RadListBoxItem("All", "All");
                rlbGender.Items.Insert(0, item);
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void LoadCharts(DataTable dt)
    {

        Color[] colorSet = { Color.Orange, Color.Yellow, Color.Green, Color.Blue, Color.Purple, Color.Orange };

        rcBar.PlotArea.Series.Clear();

        int i = 0;
        //loop through divisions
        foreach (DataRow row in dt.Rows)
        {
            ColumnSeries bs1 = new ColumnSeries();
            bs1.Name = row["Division"].ToString();
            bs1.LabelsAppearance.Visible = false;
            bs1.TooltipsAppearance.DataFormatString = "{0}%";

            try
            {
                SeriesItem si0 = new SeriesItem(Convert.ToDecimal(row["Followup_Yesp"]));
                si0.BackgroundColor = colorSet[i];
                si0.Name = "Follow Up"; 
                SeriesItem si1 = new SeriesItem(Convert.ToDecimal(row["us_yesp"]));
                si1.BackgroundColor = colorSet[i];
                si1.Name = "Ultrasound";
                SeriesItem si2 = new SeriesItem(Convert.ToDecimal(row["mri_yesp"]));
                si2.BackgroundColor = colorSet[i];
                si2.Name = "MRI";
                SeriesItem si3 = new SeriesItem(Convert.ToDecimal(row["biopsy_yesp"]));
                si3.BackgroundColor = colorSet[i];
                si3.Name = "Biopsy";
                SeriesItem si4 = new SeriesItem(Convert.ToDecimal(row["pt_Notification_yesp"]));
                si4.BackgroundColor = colorSet[i];
                si4.Name = "Patient Notified";

                bs1.Items.Add(si0);
                bs1.Items.Add(si1);
                bs1.Items.Add(si2);
                bs1.Items.Add(si3);
                bs1.Items.Add(si4);

                rcBar.PlotArea.Series.Add(bs1);

                i++;
            }

            catch (Exception ex)
            {
                Logging.WriteLogToFile(_userId, ex);
            }
        }
    }

    private DataTable GetMockUpData()
    {
        DataTable dt = new DataTable();
        dt.Columns.Add("division");
        dt.Columns.Add("TTL");
        dt.Columns.Add("followup_yes");
        dt.Columns.Add("followup_no");
        dt.Columns.Add("us_yes");
        dt.Columns.Add("us_no");
        dt.Columns.Add("mri_yes");
        dt.Columns.Add("mri_no");
        dt.Columns.Add("biopsy_yes");
        dt.Columns.Add("biopsy_no");
        dt.Columns.Add("pt_notification_yes");
        dt.Columns.Add("pt_notification_no");

        //dt.Rows.Add("National", "40000", "10000 (37.5%)", "20000 (63.5%)", "7500 (75%)", "2500 (25%)", "PORT (50%)", "PORT (50%)", "PORT (50%)", "PORT (50%)", "8000 (40%)", "12000 (60%)", "1000 (10%)", "9000 (90%)");
        //dt.Rows.Add("VISN 1", "17500", "10000 (37.5%)", "2500 (63.5%)", "750 (75%)", "250 (25%)", "700 (50%)", "700 (50%)", "700 (50%)", "700 (50%)", "800 (40%)", "1200 (60%)", "100 (10%)", "900 (90%)");
        //dt.Rows.Add("VISN 2", "17500", "10000 (37.5%)", "2500 (63.5%)", "750 (75%)", "250 (25%)", "700 (50%)", "700 (50%)", "700 (50%)", "700 (50%)", "800 (40%)", "1200 (60%)", "100 (10%)", "900 (90%)");
        //dt.Rows.Add("FAC1", "400", "150 (37.5%)", "250 (63.5%)", "75 (75%)", "25 (25%)", "70 (50%)", "70 (50%)", "70 (50%)", "70 (50%)", "80 (40%)", "120 (60%)", "10 (10%)", "90 (90%)");
        //dt.Rows.Add("PAC1", "40", "15 (37.5%)", "25 (63.5%)", "8 (80%)", "2 (20%)", "7 (50%)", "7 (50%)", "7 (50%)", "7 (50%)", "8 (40%)", "12 (60%)", "1 (10%)", "9 (90%)");

        dt.Rows.Add("National", "40", "37.5", "25", "45", "54", "43", "23", "14", "53", "23", "43");
        dt.Rows.Add("VISN 1", "40", "37.5", "25", "45", "54", "43", "23", "14", "53", "23", "43");
        dt.Rows.Add("VISN 2", "40", "37.5", "25", "45", "54", "43", "23", "14", "53", "23", "43");
        dt.Rows.Add("FAC1", "40", "37.5", "25", "45", "54", "43", "23", "14", "53", "23", "43");
        dt.Rows.Add("PAC1", "45", "33.5", "35", "47", "4", "90", "33", "44", "33", "3", "93");


        rgAggregateData.DataSource = dt;
        rgAggregateData.DataBind();
        return dt;
    }

    public string FormatData(string field)
    {
        try
        {
            return Eval(field).ToString() + " (" + Eval(field + "p").ToString() + "%)";
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
            return Eval(field).ToString();
        }
    }

    /*Only fills with All/Nat/VISN because of the large ViewState*/
    /*FAC/PAC are populated via web service load on demand*/
    public void FillDivisionTree()
    {
        try
        {
            Reports r = new Reports(_userId);

            DataSet ds = new DataSet();

            DataTable dtVISN = r.GetVISNs().Copy();
            dtVISN.TableName = "VISNs";

            ds.Tables.Add(dtVISN);

            RadTreeNode all = new RadTreeNode("All", "ALL");
            rtvDivision.Nodes.Add(all);
            all.Expanded = true;
            RadTreeNode nat = new RadTreeNode("National", "NAT");
            all.Nodes.Add(nat);

            foreach (DataRow visnRow in ds.Tables[0].Rows)
            {
                RadTreeNode visnNode = new RadTreeNode(visnRow["visnText"].ToString());
                visnNode.Value = visnRow["visnId"].ToString();
                visnNode.ExpandMode = TreeNodeExpandMode.WebService;
                all.Nodes.Add(visnNode);
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    private void CountDivisions()
    {
        try
        {
            if (rtvDivision.CheckedNodes.Count > 0)
            {
                btnCreateReport.Enabled = true;
                if (rtvDivision.CheckedNodes[0].Value == "ALL")
                {
                    foreach (RadTreeNode rtn in rtvDivision.GetAllNodes())
                    {
                        if (rtn.Level != 0)
                        {
                            rtn.Enabled = false;
                            rtn.Checked = false;
                            rtn.Selected = false;
                        }
                    }
                }
                else
                {
                    foreach (RadTreeNode rtn in rtvDivision.GetAllNodes())
                    {
                        rtn.Enabled = true;
                    }
                }
            }
            else
            {
                btnCreateReport.Enabled = false;

                foreach (RadTreeNode rtn in rtvDivision.GetAllNodes())
                {
                    rtn.Enabled = true;
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #endregion

    #region Button Events
    protected void btnGetReport_Click(object sender, EventArgs e)
    {
        CreateReport();
        rgAggregateData.DataBind();
    }
    #endregion

    #region Treeview Events

    protected void rtvDivision_NodeClick(object sender, RadTreeNodeEventArgs e)
    {
        try
        {
            if (e.Node.Selected)
            {
                e.Node.Checked = true;
            }
            else
            {
                e.Node.Checked = false;
            }

            CountDivisions();
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void rtvDivision_NodeCheck(object sender, RadTreeNodeEventArgs e)
    {
        try
        {
            if (e.Node.Checked)
            {
                e.Node.Selected = true;
            }
            else
            {
                e.Node.Selected = false;
            }

            CountDivisions();
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }



    #endregion

    #region Report Grid Events

    protected void rgAggregateData_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        if (rtvDivision.CheckedNodes.Count > 0)
        {
            CreateReport();
        }

    }

    protected void rgAggregateData_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        //Used for drill downs if needed
        //On row click, gather the row's info and set the session for selecteduser
        if ((e.CommandName == "RowClick" || e.CommandName == "Edit") && e.Item is GridDataItem)
        {
            //insert logic here
            //****
            //cancels edit form
            e.Canceled = true;
        }
    }

    protected void rgAggregateData_ItemDataBound(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridDataItem)
        {
            //GridDataItem item = (GridDataItem)e.Item;
            //if (item["Division"].Text == "My PAC Team")
            //{
            //    item["birad0"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=0'>" + item["birad0"].Text + "</a>";
            //    item["birad1"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=1'>" + item["birad1"].Text + "</a>";
            //    item["birad2"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=2'>" + item["birad2"].Text + "</a>";
            //    item["birad3"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=3'>" + item["birad3"].Text + "</a>";
            //    item["birad4"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=4'>" + item["birad4"].Text + "</a>";
            //    item["birad5"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=5'>" + item["birad5"].Text + "</a>";
            //    item["birad6"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=6'>" + item["birad6"].Text + "</a>";

            //}

            //if (rtvDivision.CheckedNodes.Count > 0)
            //{
            //    if (rtvDivision.CheckedNodes[0].Value != "ALL")
            //    {
            //        foreach (RadTreeNode rtn in rtvDivision.CheckedNodes)
            //        {
            //            if (item["Division"].Text == rtn.Text)
            //            {
            //                item.Visible = true;
            //            }
            //            else
            //            {
            //                item.Visible = false;
            //            }
            //        }

            //    }
            //}


        }

        try
        {
            if (e.Item is GridHeaderItem)
            {
                //add access keys to header items for 508
                GridHeaderItem hi = (GridHeaderItem)e.Item;

                //LinkButton pn = (LinkButton)hi["Phys_Name"].Controls[0];
                //pn.AccessKey = "p";

                //LinkButton ln = (LinkButton)hi["Last_Name"].Controls[0];
                //ln.AccessKey = "n";

                //LinkButton fn = (LinkButton)hi["First_Name"].Controls[0];
                //fn.AccessKey = "f";

                //LinkButton ssn = (LinkButton)hi["SSN"].Controls[0];
                //ssn.AccessKey = "u";

                ////add tableheader scope for 508
                //TableCell tcFirstName = hi.Cells[7];
                //tcFirstName.Attributes.Add("scope", "col");
            }

            if (e.Item is GridFilteringItem)
            {
                //Add tooltip to SSN column for 508
                GridFilteringItem filterItem = (GridFilteringItem)e.Item;
                //have to do this here because can't in custom column on front end
                //***index may change***
                //filterItem.Cells[4].ToolTip = "Filter Textbox for SSN";

                ////set tooltips for each filter button for 508
                //Button btnPN = (Button)filterItem["Phys_Name"].Controls[1];
                //btnPN.ToolTip = "Filter Physician Name";

                //Button btnLN = (Button)filterItem["Last_Name"].Controls[1];
                //btnLN.ToolTip = "Filter Last Name";

                //Button btnFN = (Button)filterItem["First_Name"].Controls[1];
                //btnFN.ToolTip = "Filter First Name";

                //Button btnSSN = (Button)filterItem["SSN"].Controls[1];
                //btnSSN.ToolTip = "Filter SSN";
            }

            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }

    }

    protected void rgAggregateData_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
            e.Item.Visible = false;
    }

    #region Export

    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();
        switch (((Button)sender).CommandName)
        {
            case "XLS":
                rgAggregateData.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                rgAggregateData.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                rgAggregateData.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                rgAggregateData.MasterTableView.ExportToWord();
                break;
        }
    }

    protected void rgAggregateData_ExcelMLExportRowCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowCreatedArgs e)
    {
        if (e.RowType == Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowType.DataRow)
        {
            if (e.Row.Cells[0] != null && ((string)e.Row.Cells[0].Data.DataItem).Contains("U"))
            {
                e.Row.Cells[0].StyleValue = "MyCustomStyle";
            }
        }
    }

    protected void rgAggregateData_ExcelMLExportStylesCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLStyleCreatedArgs e)
    {
        foreach (Telerik.Web.UI.GridExcelBuilder.StyleElement style in e.Styles)
        {
            if (style.Id == "headerStyle")
            {
                style.FontStyle.Bold = true;
                style.FontStyle.Color = System.Drawing.Color.Gainsboro;
                style.InteriorStyle.Color = System.Drawing.Color.Wheat;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "itemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.WhiteSmoke;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "alternatingItemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.LightGray;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
        }

        Telerik.Web.UI.GridExcelBuilder.StyleElement myStyle = new Telerik.Web.UI.GridExcelBuilder.StyleElement("MyCustomStyle");
        myStyle.FontStyle.Bold = true;
        myStyle.FontStyle.Italic = true;
        myStyle.InteriorStyle.Color = System.Drawing.Color.Gray;
        myStyle.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
        e.Styles.Add(myStyle);
    }

    public void ConfigureExport()
    {

        rgAggregateData.ExportSettings.ExportOnlyData = true;
        rgAggregateData.ExportSettings.IgnorePaging = true;
        rgAggregateData.ExportSettings.OpenInNewWindow = true;
        rgAggregateData.ExportSettings.HideStructureColumns = true;

        rgAggregateData.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgAggregateData.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");
    }
    #endregion

    #endregion

    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCCCR Aggregate Data Template";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion
}