﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;
using CustomFilter;

public partial class AdHoc : BasePage
{

    #region Intialize Variables
    private string _userId;
    private int rows = 0;
    bool isExport = false;
    bool runReportClick = false;
    private Reports r;
    #endregion

    #region Page Events

    protected void rgAdHoc_PreRender(object sender, System.EventArgs e)
    {
        try
        {
            if (rgAdHoc.EditItems.Count > 0 && !runReportClick) // !isMainListing)
            {
                foreach (GridDataItem item in rgAdHoc.MasterTableView.Items)
                {
                    if (item != rgAdHoc.EditItems[0])
                    {
                        item.Visible = false;
                    }
                    if (rgAdHoc.EditItems.Count > 0)
                    {
                        int i = 1;
                        i++;
                    }
                }
            }
            else
            {
                foreach (GridDataItem item in rgAdHoc.MasterTableView.Items)
                {
                    item.Edit = false;
                }
            }

            if (!rgAdHoc.MasterTableView.AllowFilteringByColumn)
            {
                setDetailDisplay(false);
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "Summary Report";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;

        try
        {
            //set the user ID variable
            _userId = _user.UserId.ToString();
            Session["Patient_ID"] = _userId;

            r = new Reports(_userId);

            if (!IsPostBack)
            {
                //Fill the facilities listbox
                FillFACs();
                FillFilters();

                Session["IsMainListing"] = true;
            }

            GridFilterMenu menu = rgAdHoc.FilterMenu;
            int i = 0;

            //loop through filter menu
            while (i < menu.Items.Count)
            {
                try
                {
                    //add tooltip and access key for 508
                    if (menu.Items[i] != null)
                    {
                        menu.Items[i].ToolTip = menu.Items[i].Text;
                        //symbols
                        int asciiChar = i + 41;
                        char charValue = Convert.ToChar(asciiChar);
                        menu.Items[i].AccessKey = charValue.ToString();
                    }
                }
                catch (Exception ex)
                {
                    Logging.WriteLogToFile(_userId, ex);
                }

                i += 1;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Private Methods
    private void FillFACs()
    {
        try
        {
            //get the user's facilities and populate listboxs
            if (r.GetFacilitiesByUserId())
            {
                // Station drop down clear existing items

                rcbFac.Items.Clear();
                rcbFac.EmptyMessage = "Select a Station";

                // VISN drop down clear existing items

                rcbVisn.Items.Clear();
                rcbVisn.EmptyMessage = "Select a VISN";

                System.Data.DataTable tVisns = new DataTable();

                SetupVisnList(tVisns);

                DataView vw = new DataView(tVisns);
                vw.Sort = "[visnId] asc";

                rcbVisn.DataSource = vw;
                rcbVisn.DataTextField = "visnText";
                rcbVisn.DataValueField = "visnId";
                rcbVisn.DataBind();

                // If there's only one option, select it for them
                if (rcbVisn.Items.Count == 1)
                {
                    rcbVisn.SelectedIndex = 0;
                    rcbVisn.Enabled = false;
                    ProcessVisnSelection();
                }
                else if (rcbVisn.Items.Count == 0)
                {
                    rcbVisn.EmptyMessage = "You do not have access to any VISNs to select";
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void FillFilters()
    {
        try
        {
            //instatiate reports
            Reports r = new Reports(_userId);

            //get the user's facilities and populate listbox
            if (r.GetPatientRaces())
            {
                //clear existing items
                rlbRace.Items.Clear();
                rlbRace.DataSource = r.dtRace;
                rlbRace.DataTextField = "description_text";
                rlbRace.DataValueField = "id";
                rlbRace.DataBind();
            }

            if (r.GetPatientGenders())
            {
                //clear existing items
                rlbGender.Items.Clear();
                rlbGender.DataSource = r.dtGender;
                rlbGender.DataTextField = "description_text";
                rlbGender.DataValueField = "id";
                rlbGender.DataBind();
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    private void CreateReport(bool dataBind)
    {
        try
        {
            string ageList = null;
            foreach (RadListBoxItem item in rlbAge.Items)
            {
                if (item.Checked == true)
                {
                    ageList += item.Value + ",";
                }
            }
            if (ageList != null)
            {
                ageList = ageList.Trim().Substring(0, ageList.Length - 1);
            }

            string raceList = null;
            foreach (RadListBoxItem item in rlbRace.Items)
            {
                if (item.Checked == true)
                {
                    raceList += item.Value + ",";
                }
            }
            if (raceList != null)
            {
                raceList = raceList.Trim().Substring(0, raceList.Length - 1);
            }

            string genderList = null;
            foreach (RadListBoxItem item in rlbGender.Items)
            {
                if (item.Checked == true)
                {
                    genderList += item.Value + ",";
                }
            }
            if (genderList != null)
            {
                genderList = genderList.Trim().Substring(0, genderList.Length - 1);
            }

            string biradList = null;
            foreach (RadListBoxItem item in rlbBirads.Items)
            {
                if (item.Checked == true)
                {
                    if (item.Value != "All")
                    {
                        biradList += item.Value + ",";
                    }
                }
            }
            if (biradList != null)
            {
                biradList = biradList.Trim().Substring(0, biradList.Length - 1);
            }

            FillReportGrid(ageList, raceList, genderList, biradList);

            if (dataBind)
                rgAdHoc.DataBind();


        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void SetupVisnList(System.Data.DataTable tVisns)
    {
        try
        {
            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "visnId";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "visnText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            tVisns.Columns.Add(idColumn);
            tVisns.Columns.Add(nameColumn);

            tVisns.PrimaryKey = new DataColumn[] { tVisns.Columns["visnId"] };

            DataRow drVisn;

            foreach (System.Data.DataRow dr in r.dtFac.Rows)
            {
                if (!tVisns.Rows.Contains(dr["visnId"]))
                {
                    drVisn = tVisns.NewRow();
                    drVisn["visnId"] = dr["visnId"];
                    drVisn["visnText"] = dr["visnText"];

                    tVisns.Rows.Add(drVisn);
                }
            }
        }


        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void FillReportGrid(string ageList, string raceList, string genderList, string biradTextList)
    {
        AdHocR ah = new AdHocR();

        try
        {
            if (rcbFac.SelectedItem != null)
            {
                //get the report data
                DataTable dt = ah.GetAdHoc(Convert.ToInt32(rcbFac.SelectedItem.Value), ageList, raceList, genderList, biradTextList);
                //DataTable dt = GetMockData();

                rows = dt.Rows.Count;

                //populates the dropdown filters
                PopulateReportFilters(dt);

                //bind the data to the grid
                rgAdHoc.DataSource = dt;

                return;
            }
            else
            {
                //if no selected facility
                rgAdHoc.DataSource = "";
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);

            //if no selected facility
            rgAdHoc.DataSource = "";
        }
    }

    //populates the dropdown filters for the respective columns
    private void PopulateReportFilters(DataTable dt)
    {
        DataTable filteredDt = Helpers.GetFilteredDataSource(rgAdHoc, dt);

        DataSetHelper dsHelper;

        dsHelper = new DataSetHelper();

        DataTable dtPAC = dsHelper.SelectDistinct("DistinctPAC", filteredDt, "team_name");
        DataTable dtPhys = dsHelper.SelectDistinct("DistinctPhys", filteredDt, "primary_care_physician");
        DataTable dtRace = dsHelper.SelectDistinct("DistinctRace", filteredDt, "race");
        DataTable dtGender = dsHelper.SelectDistinct("DistinctGender", filteredDt, "gender");

        try
        {
            foreach (GridColumn col in rgAdHoc.MasterTableView.Columns)
            {
                if (col.ColumnType == "CustomFilteringColumn")
                {
                    CustomFilteringColumn column = (CustomFilteringColumn)col;

                    if (column.DataField == "team_name")
                    {
                        (column).ListDataSource = dtPAC;
                    }
                    else if (column.DataField == "primary_care_physician")
                    {
                        (column).ListDataSource = dtPhys;
                    }
                    else if (column.DataField == "race")
                    {
                        (column).ListDataSource = dtRace;
                    }
                    else if (column.DataField == "gender")
                    {
                        (column).ListDataSource = dtGender;
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void btnReport_Click(object sender, EventArgs e)
    {
        // show/hide the details if they are displayed
        Session["IsMainListing"] = true;
        setDetailDisplay(true);

        runReportClick = true;

        if (rcbFac.SelectedIndex > -1)
        {
            CreateReport(true);
        }
    }

    #endregion

    #region Facility Dropdown Events
    protected void rcbVisn_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        btnRunReport.Enabled = false;

        ProcessVisnSelection();
    }

    protected void ProcessVisnSelection()
    {
        try
        {
            r.GetFacilitiesByUserId();

            // Station drop down clear existing items
            rcbFac.Items.Clear();
            rcbFac.Text = "";
            rcbFac.ClearSelection();

            if (rcbVisn.SelectedIndex > -1)
            {
                rcbFac.Enabled = true;

                DataColumn idColumn = new DataColumn();
                idColumn = new DataColumn();
                idColumn.DataType = System.Type.GetType("System.Int32");
                idColumn.ColumnName = "facId";
                idColumn.ReadOnly = true;
                idColumn.Unique = true;

                DataColumn nameColumn = new DataColumn();
                nameColumn = new DataColumn();
                nameColumn.DataType = System.Type.GetType("System.String");
                nameColumn.ColumnName = "facText";
                nameColumn.ReadOnly = true;
                nameColumn.Unique = true;

                DataTable facs = new DataTable();
                facs.Columns.Add(idColumn);
                facs.Columns.Add(nameColumn);

                DataRow dr;

                foreach (DataRow drFac in r.dtFac.Rows)
                {
                    if (drFac["visnId"].ToString() == rcbVisn.SelectedValue)
                    {
                        dr = facs.NewRow();
                        dr["facId"] = drFac["facId"];
                        dr["facText"] = drFac["facText"];

                        facs.Rows.Add(dr);
                    }
                }

                rcbFac.DataSource = facs;
                rcbFac.DataTextField = "facText";
                rcbFac.DataValueField = "facId";
                rcbFac.DataBind();

                // If there's only one option, select it for them
                if (rcbFac.Items.Count == 1)
                {
                    rcbFac.SelectedIndex = 0;
                    //rcbFac.Enabled = false;
                    btnRunReport.Enabled = true;
                }
            }
            else
            {
                rcbFac.Enabled = false;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void rcbFac_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            btnRunReport.Enabled = true;
        }
        else
        {
            btnRunReport.Enabled = false;
        }
    }
    #endregion

    #region Report Grid Events

    protected void rgAdHoc_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        CreateReport(false);
    }

    protected void rgAdHoc_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        try
        {

            if (e.CommandName == RadGrid.ExportToExcelCommandName)
            {
                foreach (GridCommandItem item in e.Item.OwnerTableView.GetItems(GridItemType.CommandItem))
                    item.Visible = true;
            }

            else if (e.CommandName == RadGrid.EditCommandName)  // drill-down on patient record
            {
                setDetailDisplay(false);
                Session["IsMainListing"] = false;

                Session["Patient_ID"] = (e.Item as GridDataItem).GetDataKeyValue("Patient_ID").ToString();
            }

            else if (e.CommandName == RadGrid.CancelCommandName)  // Cancel drill-down
            {
                setDetailDisplay(true);
                Session["IsMainListing"] = true;
            }

            else if (e.CommandName == "Expand")
            {
                Session["IsMainListing"] = false;
            }

            //Used for drill downs if needed
            //On row click, gather the row's info and set the session for selecteduser
            //if ((e.CommandName == "RowClick" || e.CommandName == "Edit") && e.Item is GridDataItem)
            //{
            //    //insert logic here
            //    //****
            //    //cancels edit form
            //    e.Canceled = true;
            //}
            //if (e.CommandName == RadGrid.FilterCommandName)
            //{
            //    Pair filterPair = (Pair)e.CommandArgument;

            //    switch (filterPair.Second.ToString())
            //    {
            //        case "DateScheduled":
            //            this.startDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("FromOrderDatePicker") as RadDatePicker).SelectedDate;
            //            this.endDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("ToOrderDatePicker") as RadDatePicker).SelectedDate;
            //            break;
            //        default:
            //            break;
            //    }
            //}
            if (e.CommandName == "Reset")
            {
                foreach (GridColumn column in rgAdHoc.MasterTableView.OwnerGrid.Columns)
                {
                    column.CurrentFilterFunction = GridKnownFunction.NoFilter;
                    column.CurrentFilterValue = string.Empty;
                }
                rgAdHoc.MasterTableView.FilterExpression = "";
                rgAdHoc.Rebind();
            }
            else if (e.CommandName == "Print")
            {
                bool isVisible = true;

                if (((System.Web.UI.WebControls.Button)(e.CommandSource)).Text == "Print View")
                {
                    isVisible = false;
                    ((System.Web.UI.WebControls.Button)(e.CommandSource)).Text = "Filter View";
                }
                else
                {
                    if (rgAdHoc.EditItems.Count > 0)
                        Session["IsMainListing"] = false;

                    ((System.Web.UI.WebControls.Button)(e.CommandSource)).Text = "Print View";
                }

                //br2.Visible = isVisible;
                //br3.Visible = isVisible;
                //br4.Visible = isVisible;
                lblVisn.Visible = isVisible;
                rcbVisn.Visible = isVisible;
                lblFac.Visible = isVisible;
                rcbFac.Visible = isVisible;
                pnlCohort.Visible = isVisible;
                btnRunReport.Visible = isVisible;
                pnlDescription.Visible = isVisible;
                pnlAccessibility.Visible = isVisible;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    //#region Properties used in filters
    //protected DateTime? startDate
    //{
    //    set
    //    {
    //        ViewState["strD"] = value;
    //    }
    //    get
    //    {
    //        if (ViewState["strD"] != null)
    //            return (DateTime)ViewState["strD"];
    //        else
    //            return null;
    //    }
    //}
    //protected DateTime? endDate
    //{
    //    set
    //    {
    //        ViewState["endD"] = value;
    //    }
    //    get
    //    {
    //        if (ViewState["endD"] != null)
    //            return (DateTime)ViewState["endD"];
    //        else
    //            return null;
    //    }
    //}
    #endregion


    protected void rgAdHoc_ItemDataBound(object sender, GridItemEventArgs e)
    {
        try
        {
            if (e.Item is GridHeaderItem)
            {
                //add access keys to header items for 508
                GridHeaderItem hi = (GridHeaderItem)e.Item;

                //LinkButton pn = (LinkButton)hi["OrderingPhysician"].Controls[0];
                //pn.AccessKey = "p";

                //LinkButton ln = (LinkButton)hi["PatientLastName"].Controls[0];
                //ln.AccessKey = "n";

                //LinkButton fn = (LinkButton)hi["PatientFirstName"].Controls[0];
                //fn.AccessKey = "f";

                //LinkButton ssn = (LinkButton)hi["PatientSSN"].Controls[0];
                //ssn.AccessKey = "u";

                //add tableheader scope for 508
                //TableCell tcFirstName = hi.Cells[7];
                //tcFirstName.Attributes.Add("scope", "col");
            }

            if (e.Item is GridFilteringItem)
            {
                //Add tooltip to SSN column for 508
                //GridFilteringItem filterItem = (GridFilteringItem)e.Item;
                ////have to do this here because can't in custom column on front end
                ////***index may change***
                ////filterItem.Cells[5].ToolTip = "Filter Textbox for SSN";

                ////set tooltips for each filter button for 508
                ////Button btnPN = (Button)filterItem["OrderingPhysician"].Controls[1];
                ////btnPN.ToolTip = "Filter Physician Name";

                //Button btnLN = (Button)filterItem["PatientLastName"].Controls[1];
                //btnLN.ToolTip = "Filter Last Name";

                //Button btnFN = (Button)filterItem["PatientFirstName"].Controls[1];
                //btnFN.ToolTip = "Filter First Name";

                //Button btnSSN = (Button)filterItem["PatientSSN"].Controls[1];
                //btnSSN.ToolTip = "Filter SSN";
            }

            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");

                string[] fieldNames = { };
                string reportName = "AH_";

                if (isExport)
                {
                    string columnName;
                    TableCell ctc;

                    // Inspect link fields and format accordingly for the output report

                    foreach (string columnRoot in fieldNames)
                    {
                        item = (GridDataItem)e.Item;
                        columnName = reportName + columnRoot + "_Report";
                        ctc = item[columnName];
                        Helpers.configureLinkForExport(ctc, columnRoot, reportName, "");
                    }

                    // Format cells
                    foreach (TableCell cell in e.Item.Cells)
                    {
                        cell.Style["mso-number-format"] = @"\@";
                    }
                }
                else // Not exporting, just displaying grid
                {
                    Label lbl;
                    string sData;
                    RadToolTip rtt;

                    // Inspect each link field and create links or appropriate message

                    foreach (string columnRoot in fieldNames)
                    {

                        lbl = (Label)item.FindControl("lbl" + reportName + columnRoot);
                        sData = ((System.Data.DataRowView)e.Item.DataItem)[columnRoot].ToString();
                        rtt = (RadToolTip)item.FindControl("rtt" + reportName + columnRoot);

                        Helpers.setupLink(lbl, sData, rtt, columnRoot, reportName);
                    }
                }
            }
            if (e.Item is GridCommandItem)
            {
                GridCommandItem commandItem = (GridCommandItem)e.Item;
                Button btnPrint = (Button)commandItem.FindControl("btnPrint");

                if (rows > 0)
                {
                    btnPrint.Visible = true;
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }

    }

    protected void rgAdHoc_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
        {
            e.Item.Visible = false;
        }

        if (e.Item is GridHeaderItem && !isExport && (bool)Session["IsMainListing"])
        {

            GridHeaderItem header = (GridHeaderItem)e.Item;

            //loops through all headercells, which is different than columns
            foreach (GridTableHeaderCell headerCell in header.Controls)
            {
                ImageButton img = new ImageButton();

                //if the headercell has controls, it is a column, not a columngroup
                if (headerCell.HasControls())
                {
                    //get the actual header text
                    string headerText = ((LiteralControl)headerCell.Controls[0]).Text;

                    //make sure it isn't the edit header
                    if (headerText != "&nbsp;")
                    {
                        try
                        {
                            img = setupImgButton(headerText, headerCell.HeaderID);

                            headerCell.Controls.Add(img);
                        }
                        catch (Exception ex)
                        {
                            Logging.WriteLogToFile(_userId, ex);
                        }

                        //loop through actual radgrid columns and compare to the header cells 
                        foreach (GridColumn col in rgAdHoc.Columns)
                        {

                            //test to see if there is currently a sort expression and the header cell matches the column
                            if (rgAdHoc.MasterTableView.SortExpressions.Count != 0
                                && (rgAdHoc.MasterTableView.SortExpressions[0].FieldName == col.UniqueName ||
                                    rgAdHoc.MasterTableView.SortExpressions[0].FieldName == col.SortExpression)
                                && headerText == col.HeaderText)
                            {
                                //check to see if the sort order isn't none
                                if (rgAdHoc.MasterTableView.SortExpressions[0].SortOrder != GridSortOrder.None)
                                {
                                    //if it isn't none, remove the no sort image
                                    try
                                    {
                                        headerCell.Controls.Remove(img);
                                    }
                                    catch (Exception ex)
                                    {
                                        Logging.WriteLogToFile(_userId, ex);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    ImageButton setupImgButton(string headerText, string headerID)
    {
        //create the sort button image
        ImageButton img = new ImageButton();

        img.ID = "Sort_" + headerID;
        img.AlternateText = "Sort " + headerText + " asc/desc";
        img.ImageUrl = "~/images/sort_none.gif";
        img.TabIndex = 25;
        img.ToolTip = img.AlternateText;

        switch (headerText)
        {
            case "PACT Team":
                img.AccessKey = "t";
                break;
            case "Provider Name":
                img.AccessKey = "p";
                break;
            case "Last Name, First":
                img.AccessKey = "n";
                break;
            case "Last 4":
                img.AccessKey = "s";
                break;
            case "Age":
                img.AccessKey = "a";
                break;
            case "Race":
                img.AccessKey = "r";
                break;
            case "Gender":
                img.AccessKey = "g";
                break;
            case "Patient Zip":
                img.AccessKey = "z";
                break;
        }

        return img;
    }

    #region Export

    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();
        switch (((Button)sender).CommandName)
        {
            case "XLS":
                rgAdHoc.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                rgAdHoc.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                rgAdHoc.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                rgAdHoc.MasterTableView.ExportToWord();
                break;
        }
    }

    protected void rgAdHoc_ExcelMLExportRowCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowCreatedArgs e)
    {
        if (e.RowType == Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowType.DataRow)
        {
            if (e.Row.Cells[0] != null && ((string)e.Row.Cells[0].Data.DataItem).Contains("U"))
            {
                e.Row.Cells[0].StyleValue = "MyCustomStyle";
            }
        }
    }

    protected void rgAdHoc_ExcelMLExportStylesCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLStyleCreatedArgs e)
    {
        foreach (Telerik.Web.UI.GridExcelBuilder.StyleElement style in e.Styles)
        {
            if (style.Id == "headerStyle")
            {
                style.FontStyle.Bold = true;
                style.FontStyle.Color = System.Drawing.Color.Gainsboro;
                style.InteriorStyle.Color = System.Drawing.Color.Wheat;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "itemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.WhiteSmoke;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "alternatingItemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.LightGray;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
        }

        Telerik.Web.UI.GridExcelBuilder.StyleElement myStyle = new Telerik.Web.UI.GridExcelBuilder.StyleElement("MyCustomStyle");
        myStyle.FontStyle.Bold = true;
        myStyle.FontStyle.Italic = true;
        myStyle.InteriorStyle.Color = System.Drawing.Color.Gray;
        myStyle.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
        e.Styles.Add(myStyle);
    }

    public void ConfigureExport()
    {
        rgAdHoc.ExportSettings.ExportOnlyData = true;
        rgAdHoc.ExportSettings.IgnorePaging = true;
        rgAdHoc.ExportSettings.OpenInNewWindow = true;
        rgAdHoc.ExportSettings.HideStructureColumns = true;

        rgAdHoc.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgAdHoc.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");

        rgAdHoc.ExportSettings.OpenInNewWindow = true;

        foreach (GridColumn col in rgAdHoc.MasterTableView.RenderColumns)
        {
            if (col.UniqueName.EndsWith("Report"))
                col.Visible = true;
            else if (col.UniqueName.EndsWith("GUI") || col.UniqueName == "EditCommandColumn")
                col.Visible = false;
        }
        rgAdHoc.Rebind();
    }

    protected void setDetailDisplay(bool show)
    {
        GridItem cmdItem = rgAdHoc.MasterTableView.GetItems(GridItemType.CommandItem)[0];
        Button btnReset = (Button)cmdItem.FindControl("btnReset");
        btnReset.Visible = show;

        rgAdHoc.MasterTableView.AllowFilteringByColumn = show;
        rgAdHoc.MasterTableView.AllowSorting = show;
    }
    #endregion

    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCCCR AdHoc Report";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion
}