﻿using System;
using System.Data;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;
using CustomFilter;

public partial class AllMamWithBiRad : BasePage
{

    #region Intialize Variables
    private string _userId;
    bool isExport = false;
    private Reports r;
    private const string ALL_MAMMOGRAMS_DESCRIPTION = "bcr.AllMammograms.Description";
    #endregion

    #region Page Events
    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "All Mammograms";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;



        try
        {
            //set the user ID variable
            _userId = _user.UserId.ToString();
            r = new Reports(_userId);  

            #region Set Date Params
            fromDate.MaxDate = DateTime.Today;
            toDate.MaxDate = DateTime.Today;
            #endregion

            if (!IsPostBack)
            {
                //Fill the facilities listbox
                FillFACs();    
 
                AllMammogramsDescription.Text = HttpUtility.HtmlDecode(
                    r.GetSetting(ALL_MAMMOGRAMS_DESCRIPTION, _user.RegistryId).ToString());

                if (Request.QueryString["birad"] != null)
                {
                    FillReportGrid();
                    rgAllMamWithBiRad.MasterTableView.FilterExpression = "BiRadCode=" + Request.QueryString["birad"].ToString();
                    rgAllMamWithBiRad.Rebind();
                }

                //set date
                fromDate.SelectedDate = DateTime.Today.AddYears(-1);
                toDate.SelectedDate = DateTime.Today;
            }

            #region Filter menu modification
            GridFilterMenu menu = rgAllMamWithBiRad.FilterMenu;
            int i = 0;

            //loop through filter menu
            while (i < menu.Items.Count)
            {
                try
                {
                    //add tooltip and access key for 508
                    if (menu.Items[i] != null)
                    {
                        menu.Items[i].ToolTip = menu.Items[i].Text;
                        //symbols
                        int asciiChar = i + 41;
                        char charValue = Convert.ToChar(asciiChar);
                        menu.Items[i].AccessKey = charValue.ToString();
                    }
                }
                catch (Exception ex)
                {
                    Logging.WriteLogToFile(_userId, ex);
                }

                i += 1;
            }
            #endregion
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Private Methods
    private void FillFACs()
    {
        try
        {
            //get the user's facilities and populate listboxs
            if (r.GetFacilitiesByUserId())
            {
                // Station drop down clear existing items

                rcbFac.Items.Clear();
                rcbFac.EmptyMessage = "Select a Station";

                // VISN drop down clear existing items

                rcbVisn.Items.Clear();
                rcbVisn.EmptyMessage = "Select a VISN";

                System.Data.DataTable tVisns = new DataTable();

                SetupVisnList(tVisns);

                DataView vw = new DataView(tVisns);
                vw.Sort = "[visnId] asc";

                rcbVisn.DataSource = vw;
                rcbVisn.DataTextField = "visnText";
                rcbVisn.DataValueField = "visnId";
                rcbVisn.DataBind();

                // If there's only one option, select it for them
                if (rcbVisn.Items.Count == 1)
                {
                    rcbVisn.SelectedIndex = 0;
                    rcbVisn.Enabled = false;
                    ProcessVisnSelection();
                }
                else if (rcbVisn.Items.Count == 0)
                {
                    rcbVisn.EmptyMessage = "You do not have access to any VISNs to select";
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void SetupVisnList(System.Data.DataTable tVisns)
    {
        try
        {
            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "visnId";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "visnText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            tVisns.Columns.Add(idColumn);
            tVisns.Columns.Add(nameColumn);

            tVisns.PrimaryKey = new DataColumn[] { tVisns.Columns["visnId"] };

            DataRow drVisn;

            foreach (System.Data.DataRow dr in r.dtFac.Rows)
            {
                if (!tVisns.Rows.Contains(dr["visnId"]))
                {
                    drVisn = tVisns.NewRow();
                    drVisn["visnId"] = dr["visnId"];
                    drVisn["visnText"] = dr["visnText"];

                    tVisns.Rows.Add(drVisn);
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private DataTable GetMockData()
    {
        DataTable dt = new DataTable();
        dt.Columns.Add("id");
        dt.Columns.Add("team_name");
        dt.Columns.Add("primary_care_physician");
        dt.Columns.Add("PatientLastName");
        dt.Columns.Add("PatientFirstName");
        dt.Columns.Add("PatientSSN");
        dt.Columns.Add("BiRadCode");
        dt.Columns.Add("age");
        dt.Columns.Add("race");
        dt.Columns.Add("DateOfLastMammogram");
        dt.Columns.Add("gender");
        dt.Columns.Add("treatment_zip");
        dt.Columns.Add("patient_zip");
        dt.Columns.Add("ultrasound");
        dt.Columns.Add("MRI");
        dt.Columns.Add("biopsy");
        dt.Columns.Add("fna");
        dt.Columns.Add("onc");


        dt.Rows.Add("1", "PACTeam1", "Brown, John", "Martin", "Mary", "***-**-1234", "0", "45", "White", "1/15/2012", "Female", "22901", "22901", "US Result 1", "MRI Result 1", "Biopsy Result 1", "FNA Result 1", "Yes");
        dt.Rows.Add("2", "PACTeam1", "Brown, John", "Sampson", "Jessica", "***-**-4567", "1", "54", "White", "2/15/2012 8:00 AM", "Female", "22901", "22902", "US Result 2", "MRI Result 2", "Biopsy Result 2", "FNA Result 2", "Yes");
        dt.Rows.Add("3", "PACTeam2", "Brown, John", "Davis", "Beth", "***-**-7890", "2", "53", "White", "3/15/2012", "Female", "22901", "22902", "US Result 1", "MRI Result 3", "Biopsy Result 3", "FNA Result 3", "Yes");
        dt.Rows.Add("4", "PACTeam1", "Doe, Jane", "Smith", "Alexandria", "***-**-0123", "2", "20", "African-American", "3/21/2012", "Female", "22901", "22903", "US Result 4", "MRI Result 4", "Biopsy Result 4", "FNA Result 3", "No");
        dt.Rows.Add("5", "PACTeam4", "Does, Jane", "Hawkins", "Andrea", "***-**-3456", "3", "68", "Asian", "5/15/2012", "Female", "22901", "22901", "US Result 6", "MRI Result 4", "Biopsy Result 5", "FNA Result 5", "Yes");
        dt.Rows.Add("6", "PACTeam1", "Brown, John", "Donald", "Lisa", "***-**-6789", "5", "55", "White", "6/15/2012", "Female", "22901", "22901", "US Result 1", "MRI Result 1", "Biopsy Result 1", "FNA Result 1", "Yes");
        dt.Rows.Add("7", "PACTeam6", "Martinez, Sue", "Davis", "Lauren", "***-**-9012", "4", "55", "Hispanic", "7/15/2012", "Female", "22901", "22901", "US Result 1", "MRI Result 1", "Biopsy Result 1", "FNA Result 1", "No");
        dt.Rows.Add("8", "PACTeam1", "Doe, Jane", "Smithfield", "Alexa", "***-**-2345", "0", "47", "White", "8/15/2012", "Female", "22901", "22901", "US Result 1", "MRI Result 1", "Biopsy Result 1", "FNA Result 1", "Yes");
        dt.Rows.Add("9", "PACTeam7", "Martinez, Sue", "Garber", "Lauren", "***-**-5678", "5", "35", "White", "9/15/2012", "Female", "22901", "22901", "US Result 1", "MRI Result 1", "Biopsy Result 1", "FNA Result 1", "Yes");

        return dt;
    }

    private void FillReportGrid()
    {
        PatientData pd = new PatientData();

        try
        {
            if (rcbFac.SelectedItem != null)
            {
                //get the report data
                DataTable dt = pd.GetAllMamWithBiRad(rcbFac.SelectedItem.Value, fromDate.DbSelectedDate.ToString(), toDate.DbSelectedDate.ToString());
                //DataTable dt = GetMockData();

                //populates the dropdown filters
                PopulateReportFilters(dt);

                //bind the data to the grid
                rgAllMamWithBiRad.DataSource = dt;
                return;
            }
            //if no selected facility
            rgAllMamWithBiRad.DataSource = "";
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);

            //if no selected facility
            rgAllMamWithBiRad.DataSource = "";
        }
    }

    //populates the dropdown filters for the respective columns
    private void PopulateReportFilters(DataTable dt)
    {
        DataTable filteredDt = Helpers.GetFilteredDataSource(rgAllMamWithBiRad, dt);

        DataSetHelper dsHelper;

        dsHelper = new DataSetHelper();

        DataTable dtPAC = dsHelper.SelectDistinct("DistinctPAC", filteredDt, "team_name");
        DataTable dtBiRad = dsHelper.SelectDistinct("DistinctBiRad", filteredDt, "Bi_Rad_Code");
        DataTable dtPhys = dsHelper.SelectDistinct("DistinctPhys", filteredDt, "primary_care_physician");
        DataTable dtONC = dsHelper.SelectDistinct("DistinctONC", filteredDt, "oncology_visit");
        DataTable dtRace = dsHelper.SelectDistinct("DistinctRace", filteredDt, "race");
        DataTable dtGender = dsHelper.SelectDistinct("DistinctGender", filteredDt, "gender");
        DataTable dtOrderProv = dsHelper.SelectDistinct("DistinctPhys", filteredDt, "ordering_provider");

        try
        {
            foreach (GridColumn col in rgAllMamWithBiRad.MasterTableView.Columns)
            {
                if (col.ColumnType == "CustomFilteringColumn")
                {
                    CustomFilteringColumn column = (CustomFilteringColumn)col;

                    if (column.DataField == "team_name")
                    {
                        (column).ListDataSource = dtPAC;
                    }
                    else if (column.DataField == "oncology_visit")
                    {
                        (column).ListDataSource = dtONC;
                    }
                    else if (column.DataField == "Bi_Rad_Code")
                    {
                        (column).ListDataSource = dtBiRad;
                    }
                    else if (column.DataField == "primary_care_physician")
                    {
                        (column).ListDataSource = dtPhys;
                    }
                    else if (column.DataField == "race")
                    {
                        (column).ListDataSource = dtRace;
                    }
                    else if (column.DataField == "gender")
                    {
                        (column).ListDataSource = dtGender;
                    }
                    else if (column.DataField == "ordering_provider")
                    {
                        (column).ListDataSource = dtOrderProv;
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void btnReport_Click(object sender, EventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            FillReportGrid();
            rgAllMamWithBiRad.DataBind();
        }
    }

    #endregion

    #region Facility Dropdown Events
    protected void rcbVisn_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        ProcessVisnSelection();
    }

    protected void ProcessVisnSelection()
    {
        r.GetFacilitiesByUserId();

        // Station drop down clear existing items
        rcbFac.Items.Clear();
        rcbFac.Text = "";
        rcbFac.ClearSelection();

        if (rcbVisn.SelectedIndex > -1)
        {
            rcbFac.Enabled = true;

            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "facId";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "facText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            DataTable facs = new DataTable();
            facs.Columns.Add(idColumn);
            facs.Columns.Add(nameColumn);

            DataRow dr;

            foreach (DataRow drFac in r.dtFac.Rows)
            {
                if (drFac["visnId"].ToString() == rcbVisn.SelectedValue)
                {
                    dr = facs.NewRow();
                    dr["facId"] = drFac["facId"];
                    dr["facText"] = drFac["facText"];

                    facs.Rows.Add(dr);
                }
            }

            rcbFac.DataSource = facs;
            rcbFac.DataTextField = "facText";
            rcbFac.DataValueField = "facId";
            rcbFac.DataBind();

            // If there's only one option, select it for them
            if (rcbFac.Items.Count == 1)
            {
                rcbFac.SelectedIndex = 0;
                //rcbFac.Enabled = false;
                btnRunReport.Enabled = true;
            }
        }
        else
        {
            rcbFac.Enabled = false;
        }
    }
    
    protected void rcbFac_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            btnRunReport.Enabled = true;
        }
        else
        {
            btnRunReport.Enabled = false;
        }
    }
    #endregion

    #region Report Grid Events

    protected void rgAllMamWithBiRad_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        FillReportGrid();
    }

    protected void rgAllMamWithBiRad_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        try
        {
            //Used for drill downs if needed
            //On row click, gather the row's info and set the session for selecteduser
            //if ((e.CommandName == "RowClick" || e.CommandName == "Edit") && e.Item is GridDataItem)
            //{
            //    //insert logic here
            //    //****
            //    //cancels edit form
            //    e.Canceled = true;
            //}
            if (e.CommandName == RadGrid.FilterCommandName)
            {
                Pair filterPair = (Pair)e.CommandArgument;

                switch (filterPair.Second.ToString())
                {
                    case "Date_Of_Last_Mammogram":
                        this.startDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("FromDatePicker") as RadDatePicker).SelectedDate;
                        this.endDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("ToDatePicker") as RadDatePicker).SelectedDate;
                        break;
                    default:
                        break;
                }
            }
            if (e.CommandName == "Reset")
            {
                foreach (GridColumn column in rgAllMamWithBiRad.MasterTableView.OwnerGrid.Columns)
                {
                    column.CurrentFilterFunction = GridKnownFunction.NoFilter;
                    column.CurrentFilterValue = string.Empty;
                }
                rgAllMamWithBiRad.MasterTableView.FilterExpression = "";
                rgAllMamWithBiRad.Rebind();
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #region Properties used in filters
    protected DateTime? startDate
    {
        set
        {
            ViewState["strD"] = value;
        }
        get
        {
            if (ViewState["strD"] != null)
                return (DateTime)ViewState["strD"];
            else
                return null;
        }
    }
    protected DateTime? endDate
    {
        set
        {
            ViewState["endD"] = value;
        }
        get
        {
            if (ViewState["endD"] != null)
                return (DateTime)ViewState["endD"];
            else
                return null;
        }
    }
    #endregion

    protected void rgAllMamWithBiRad_ItemDataBound(object sender, GridItemEventArgs e)
    {
        try
        {
            if (e.Item is GridHeaderItem)
            {
                //add access keys to header items for 508
                GridHeaderItem hi = (GridHeaderItem)e.Item;

                //LinkButton pn = (LinkButton)hi["OrderingPhysician"].Controls[0];
                //pn.AccessKey = "p";

                //LinkButton ln = (LinkButton)hi["PatientLastName"].Controls[0];
                //ln.AccessKey = "n";

                //LinkButton fn = (LinkButton)hi["PatientFirstName"].Controls[0];
                //fn.AccessKey = "f";

                //LinkButton ssn = (LinkButton)hi["PatientSSN"].Controls[0];
                //ssn.AccessKey = "u";

                //add tableheader scope for 508
                //TableCell tcFirstName = hi.Cells[7];
                //tcFirstName.Attributes.Add("scope", "col");
            }

            if (e.Item is GridFilteringItem)
            {
                //Add tooltip to SSN column for 508
                //GridFilteringItem filterItem = (GridFilteringItem)e.Item;
                ////have to do this here because can't in custom column on front end
                ////***index may change***
                ////filterItem.Cells[5].ToolTip = "Filter Textbox for SSN";

                ////set tooltips for each filter button for 508
                ////Button btnPN = (Button)filterItem["OrderingPhysician"].Controls[1];
                ////btnPN.ToolTip = "Filter Physician Name";

                //Button btnLN = (Button)filterItem["PatientLastName"].Controls[1];
                //btnLN.ToolTip = "Filter Last Name";

                //Button btnFN = (Button)filterItem["PatientFirstName"].Controls[1];
                //btnFN.ToolTip = "Filter First Name";

                //Button btnSSN = (Button)filterItem["PatientSSN"].Controls[1];
                //btnSSN.ToolTip = "Filter SSN";
            }

            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");

                string[] fieldNames = {"BI_RADS_follow_up","US_Result","MRI_Result","Biopsy_Result",
                                       "Oncology_Visit","Pathology_Result"};
                string reportName = "AMWBR_";

                if (isExport)
                {
                    string columnName;
                    TableCell ctc;

                    // Inspect link fields and format accordingly for the output report

                    foreach (string columnRoot in fieldNames)
                    {
                        item = (GridDataItem)e.Item;
                        columnName = reportName + columnRoot + "_Report";
                        ctc = item[columnName];
                        Helpers.configureLinkForExport(ctc, columnRoot, reportName, "");
                    }

                    // Format cells
                    foreach (TableCell cell in e.Item.Cells)
                    {
                        cell.Style["mso-number-format"] = @"\@";
                    }
                }
                else // Not exporting, just displaying grid
                {
                    Label lbl;
                    string sData;
                    RadToolTip rtt;

                    // Inspect each link field and create links or appropriate message

                    foreach (string columnRoot in fieldNames)
                    {

                        lbl = (Label)item.FindControl("lbl" + reportName + columnRoot);
                        sData = ((System.Data.DataRowView)e.Item.DataItem)[columnRoot].ToString();
                        rtt = (RadToolTip)item.FindControl("rtt" + reportName + columnRoot);

                        Helpers.setupLink(lbl, sData, rtt, columnRoot, reportName);
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }

    }

    protected void rgAllMamWithBiRad_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
            e.Item.Visible = false;

        if (e.Item is GridHeaderItem && !isExport)
        {
            GridHeaderItem header = (GridHeaderItem)e.Item;

            //loops through all headercells, which is different than columns
            foreach (GridTableHeaderCell headerCell in header.Controls)
            {
                ImageButton img = new ImageButton();

                //if the headercell has controls, it is a column, not a columngroup
                if (headerCell.HasControls())
                {
                    //get the actual header text
                    string headerText = ((LiteralControl)headerCell.Controls[0]).Text;

                    //make sure it isn't the edit header
                    if (headerText != "&nbsp;")
                    {
                        try
                        {
                            img = setupImgButton(headerText, headerCell.HeaderID);

                            headerCell.Controls.Add(img);
                        }
                        catch (Exception ex)
                        {
                            Logging.WriteLogToFile(_userId, ex);
                        }

                        //loop through actual radgrid columns and compare to the header cells 
                        foreach (GridColumn col in rgAllMamWithBiRad.Columns)
                        {
                            //test to see if there is currently a sort expression and the header cell matches the column
                            if (rgAllMamWithBiRad.MasterTableView.SortExpressions.Count != 0
                                && (rgAllMamWithBiRad.MasterTableView.SortExpressions[0].FieldName == col.UniqueName
                                    || rgAllMamWithBiRad.MasterTableView.SortExpressions[0].FieldName == col.SortExpression)
                                && headerText == col.HeaderText)
                            {
                                //check to see if the sort order isn't none
                                if (rgAllMamWithBiRad.MasterTableView.SortExpressions[0].SortOrder != GridSortOrder.None)
                                {
                                    //if it isn't none, remove the no sort image
                                    try
                                    {
                                        headerCell.Controls.Remove(img);
                                    }
                                    catch (Exception ex)
                                    {
                                        Logging.WriteLogToFile(_userId, ex);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    ImageButton setupImgButton(string headerText, string headerID)
    {
        //create the sort button image
        ImageButton img = new ImageButton();

        img.ID = "Sort_" + headerID;
        img.AlternateText = "Sort " + headerText + " asc/desc";
        img.ImageUrl = "~/images/sort_none.gif";
        img.TabIndex = 25;
        img.ToolTip = img.AlternateText;

        switch (headerText)
        {
            case "PACT Team":
                img.AccessKey = "t";
                break;
            case "Provider Name":
                img.AccessKey = "p";
                break;
            case "Last Name, First":
                img.AccessKey = "n";
                break;
            case "Last 4":
                img.AccessKey = "s";
                break;
            case "Age":
                img.AccessKey = "a";
                break;
            case "Race":
                img.AccessKey = "r";
                break;
            case "Gender":
                img.AccessKey = "g";
                break;
            case "Patient Zip":
                img.AccessKey = "z";
                break;
            case "Date Performed":  // Mammogram
                img.AccessKey = "m";
                break;
            case "BI-RADS Code":
                img.AccessKey = "b";
                break;
            case "BI-RADS Follow-up Action Taken":
                img.AccessKey = "f";
                break;
            case "Procedure Location":  
                img.AccessKey = "l";
                break;
            case "Ultrasound":
                img.AccessKey = "u";
                break;
            case "MRI":
                img.AccessKey = "i";
                break;
            case "Ordering Provider":
                img.AccessKey = "j";    
                break;
            case "Biopsy Results":
                img.AccessKey = "y";
                break;
            case "Oncology visit":
                img.AccessKey = "o";
                break;
            default:
                break;
        }

        return img;
    }

    #region Export

    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();
        switch (((Button)sender).CommandName)
        {
            case "XLS":
                rgAllMamWithBiRad.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                rgAllMamWithBiRad.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                rgAllMamWithBiRad.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                rgAllMamWithBiRad.MasterTableView.ExportToWord();
                break;
        }
    }

    protected void rgAllMamWithBiRad_ExcelMLExportRowCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowCreatedArgs e)
    {
        if (e.RowType == Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowType.DataRow)
        {
            if (e.Row.Cells[0] != null && ((string)e.Row.Cells[0].Data.DataItem).Contains("U"))
            {
                e.Row.Cells[0].StyleValue = "MyCustomStyle";
            }
        }
    }

    protected void rgAllMamWithBiRad_ExcelMLExportStylesCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLStyleCreatedArgs e)
    {
        foreach (Telerik.Web.UI.GridExcelBuilder.StyleElement style in e.Styles)
        {
            if (style.Id == "headerStyle")
            {
                style.FontStyle.Bold = true;
                style.FontStyle.Color = System.Drawing.Color.Gainsboro;
                style.InteriorStyle.Color = System.Drawing.Color.Wheat;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "itemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.WhiteSmoke;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "alternatingItemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.LightGray;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
        }

        Telerik.Web.UI.GridExcelBuilder.StyleElement myStyle = new Telerik.Web.UI.GridExcelBuilder.StyleElement("MyCustomStyle");
        myStyle.FontStyle.Bold = true;
        myStyle.FontStyle.Italic = true;
        myStyle.InteriorStyle.Color = System.Drawing.Color.Gray;
        myStyle.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
        e.Styles.Add(myStyle);
    }

    public void ConfigureExport()
    {
        rgAllMamWithBiRad.ExportSettings.ExportOnlyData = true;
        rgAllMamWithBiRad.ExportSettings.IgnorePaging = true;
        rgAllMamWithBiRad.ExportSettings.OpenInNewWindow = true;
        rgAllMamWithBiRad.ExportSettings.HideStructureColumns = true;

        rgAllMamWithBiRad.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgAllMamWithBiRad.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");

        foreach (GridColumn col in rgAllMamWithBiRad.MasterTableView.RenderColumns)
        {
            if (col.UniqueName.EndsWith("Report"))
                col.Visible = true;
            else if (col.UniqueName.EndsWith("GUI") || col.UniqueName == "EditCommandColumn")
                col.Visible = false;
        }
        rgAllMamWithBiRad.Rebind(); 
    }
    #endregion

    #endregion

    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCCCR All Mammograms w/BI-RADS Report";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion



}