﻿using System;
using System.Data;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;
using CustomFilter;

public partial class AllMamWithResults : BasePage
{

    #region Intialize Variables
    private string _userId;
    bool isExport = false;
    #endregion

    #region Page Events
    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "All Mammograms w/Results";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;

        try
        {
            //set the user ID variable
            _userId = _user.UserId.ToString();

            #region Set Date Params
            toDate.MaxDate = DateTime.Today;
            #endregion

            if (!IsPostBack)
            {
                //Fill the facilities listbox
                FillFACs();

                if (Request.QueryString["birad"] != null)
                {
                    FillReportGrid();
                    rgAllMamWithResults.MasterTableView.FilterExpression = "BiRadCode=" + Request.QueryString["birad"].ToString();
                    rgAllMamWithResults.Rebind();
                }

                //set date
                fromDate.SelectedDate = DateTime.Today.AddYears(-1);
                toDate.SelectedDate = DateTime.Today;

            }

            #region Filter menu modification
            GridFilterMenu menu = rgAllMamWithResults.FilterMenu;
            int i = 0;

            //loop through filter menu
            while (i < menu.Items.Count)
            {
                try
                {
                    //add tooltip and access key for 508
                    if (menu.Items[i] != null)
                    {
                        menu.Items[i].ToolTip = menu.Items[i].Text;
                        //symbols
                        int asciiChar = i + 41;
                        char charValue = Convert.ToChar(asciiChar);
                        menu.Items[i].AccessKey = charValue.ToString();
                    }
                }
                catch (Exception ex)
                {
                    Logging.WriteLogToFile(_userId, ex);
                }

                i += 1;
            }
            #endregion
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Private Methods
    private void FillFACs()
    {
        try
        {
            //instatiate reports
            Reports r = new Reports(_userId);

            //get the user's facilities and populate listbox
            if (r.GetFacilitiesByUserId())
            {
                //clear existing items
                rcbFac.Items.Clear();
                rcbFac.EmptyMessage = "Select a Station";
                rcbFac.DataSource = r.dtFac;
                rcbFac.DataTextField = "facText";
                rcbFac.DataValueField = "facId";
                rcbFac.DataBind();
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private DataTable GetMockData()
    {
        DataTable dt = new DataTable();
        dt.Columns.Add("id");
        dt.Columns.Add("PACTeam");
        dt.Columns.Add("OrderingPhysician");
        dt.Columns.Add("PatientLastName");
        dt.Columns.Add("PatientFirstName");
        dt.Columns.Add("PatientSSN");
        dt.Columns.Add("BiRadCode");
        dt.Columns.Add("DateOfLastMammogram");
        dt.Columns.Add("DateOrdered");
        dt.Columns.Add("DateScheduled");

        dt.Rows.Add("1", "PACTeam1", "Brown, John", "Martin", "Mary", "***-**-1234", "0", "1/26/2011", "1/13/2012", "1/15/2012");
        dt.Rows.Add("2", "PACTeam1", "Brown, John", "Sampson", "Jessica", "***-**-4567", "1", "2/26/2011", "2/13/2012", "2/15/2012");
        dt.Rows.Add("3", "PACTeam2", "Brown, John", "Davis", "Beth", "***-**-7890", "2", "3/26/2011", "3/13/2012", "3/15/2012");
        dt.Rows.Add("4", "PACTeam1", "Doe, Jane", "Smith", "Alexandria", "***-**-0123", "2", "4/26/2011", "4/13/2012", "4/15/2012");
        dt.Rows.Add("5", "PACTeam4", "Does, Jane", "Hawkins", "Andrea", "***-**-3456", "3", "5/26/2011", "5/13/2012", "5/15/2012");
        dt.Rows.Add("6", "PACTeam1", "Brown, John", "Donald", "Lisa", "***-**-6789", "5", "6/26/2011", "6/13/2012", "6/15/2012");
        dt.Rows.Add("7", "PACTeam6", "Martinez, Sue", "Davis", "Lauren", "***-**-9012", "4", "7/26/2011", "7/13/2012", "7/15/2012");
        dt.Rows.Add("8", "PACTeam1", "Doe, Jane", "Smithfield", "Alexa", "***-**-2345", "0", "8/26/2011", "8/13/2012", "8/15/2012");
        dt.Rows.Add("9", "PACTeam7", "Martinez, Sue", "Garber", "Lauren", "***-**-5678", "5", "9/26/2011", "9/13/2012", "9/15/2012");

        return dt;
    }

    private void FillReportGrid()
    {
        PatientData pd = new PatientData();

        try
        {
            //if (rcbFac.SelectedItem != null)
            //{
            //get the report data
            DataTable dt = pd.GetAllMamWithResults(rcbFac.SelectedItem.Value, fromDate.DbSelectedDate.ToString(), toDate.DbSelectedDate.ToString());
            //DataTable dt = GetMockData();

            //populates the dropdown filters
            PopulateReportFilters(dt);

            //bind the data to the grid
            rgAllMamWithResults.DataSource = dt;
            //return;
            //}
            //if no selected facility

        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);

            //if no selected facility
            rgAllMamWithResults.DataSource = "";
        }
    }

    //populates the dropdown filters for the respective columns
    private void PopulateReportFilters(DataTable dt)
    {

        DataSetHelper dsHelper;

        dsHelper = new DataSetHelper();

        DataTable dtPAC = dsHelper.SelectDistinct("DistinctPAC", dt, "Team_Name");
        DataTable dtPhys = dsHelper.SelectDistinct("DistinctPhys", dt, "Primary_Care_Physician");
        DataTable dtBiRad = dsHelper.SelectDistinct("DistinctBiRad", dt, "BiRad_Code");

        try
        {
            foreach (GridColumn col in rgAllMamWithResults.MasterTableView.Columns)
            {
                if (col.ColumnType == "CustomFilteringColumn")
                {
                    CustomFilteringColumn column = (CustomFilteringColumn)col;

                    if (column.DataField == "Team_Name")
                    {
                        (column).ListDataSource = dtPAC;
                    }
                    else if (column.DataField == "Primary_Care_Physician")
                    {
                        (column).ListDataSource = dtPhys;
                    }
                    else if (column.DataField == "BiRad_Code")
                    {
                        (column).ListDataSource = dtBiRad;
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void btnReport_Click(object sender, EventArgs e)
    {
        if (rcbFac.SelectedIndex > 0)
        {
            FillReportGrid();
            rgAllMamWithResults.DataBind();
        }
    }

    #endregion

    #region Facility Dropdown Events
    protected void rcbFac_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            btnRunReport.Enabled = true;
        }
        else
        {
            btnRunReport.Enabled = false;
        }
    }
    #endregion

    #region Report Grid Events

    protected void rgAllMamWithResults_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        FillReportGrid();
    }

    protected void rgAllMamWithResults_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        try
        {
            //Used for drill downs if needed
            //On row click, gather the row's info and set the session for selecteduser
            if ((e.CommandName == "RowClick" || e.CommandName == "Edit") && e.Item is GridDataItem)
            {
                //insert logic here
                //****
                //cancels edit form
                e.Canceled = true;
            }
            if (e.CommandName == RadGrid.FilterCommandName)
            {
                Pair filterPair = (Pair)e.CommandArgument;

                switch (filterPair.Second.ToString())
                {
                    case "DateScheduled":
                        this.startDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("FromOrderDatePicker") as RadDatePicker).SelectedDate;
                        this.endDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("ToOrderDatePicker") as RadDatePicker).SelectedDate;
                        break;
                    default:
                        break;
                }
            }
            if (e.CommandName == "Reset")
            {
                foreach (GridColumn column in rgAllMamWithResults.MasterTableView.OwnerGrid.Columns)
                {
                    column.CurrentFilterFunction = GridKnownFunction.NoFilter;
                    column.CurrentFilterValue = string.Empty;
                }
                rgAllMamWithResults.MasterTableView.FilterExpression = "";
                rgAllMamWithResults.Rebind();
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #region Properties used in filters
    protected DateTime? startDate
    {
        set
        {
            ViewState["strD"] = value;
        }
        get
        {
            if (ViewState["strD"] != null)
                return (DateTime)ViewState["strD"];
            else
                return null;
        }
    }
    protected DateTime? endDate
    {
        set
        {
            ViewState["endD"] = value;
        }
        get
        {
            if (ViewState["endD"] != null)
                return (DateTime)ViewState["endD"];
            else
                return null;
        }
    }
    #endregion

    protected void rgAllMamWithResults_ItemDataBound(object sender, GridItemEventArgs e)
    {
        try
        {
            if (e.Item is GridHeaderItem)
            {
                //add access keys to header items for 508
                GridHeaderItem hi = (GridHeaderItem)e.Item;

                //LinkButton pn = (LinkButton)hi["OrderingPhysician"].Controls[0];
                //pn.AccessKey = "p";

                //LinkButton ln = (LinkButton)hi["PatientLastName"].Controls[0];
                //ln.AccessKey = "n";

                //LinkButton fn = (LinkButton)hi["PatientFirstName"].Controls[0];
                //fn.AccessKey = "f";

                //LinkButton ssn = (LinkButton)hi["PatientSSN"].Controls[0];
                //ssn.AccessKey = "u";

                //add tableheader scope for 508
                //TableCell tcFirstName = hi.Cells[7];
                //tcFirstName.Attributes.Add("scope", "col");
            }

            if (e.Item is GridFilteringItem)
            {
                //Add tooltip to SSN column for 508
                //GridFilteringItem filterItem = (GridFilteringItem)e.Item;
                ////have to do this here because can't in custom column on front end
                ////***index may change***
                ////filterItem.Cells[5].ToolTip = "Filter Textbox for SSN";

                ////set tooltips for each filter button for 508
                ////Button btnPN = (Button)filterItem["OrderingPhysician"].Controls[1];
                ////btnPN.ToolTip = "Filter Physician Name";

                //Button btnLN = (Button)filterItem["PatientLastName"].Controls[1];
                //btnLN.ToolTip = "Filter Last Name";

                //Button btnFN = (Button)filterItem["PatientFirstName"].Controls[1];
                //btnFN.ToolTip = "Filter First Name";

                //Button btnSSN = (Button)filterItem["PatientSSN"].Controls[1];
                //btnSSN.ToolTip = "Filter SSN";
            }

            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void rgAllMamWithResults_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
            e.Item.Visible = false;
    }

    #region Export

    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();
        switch (((Button)sender).CommandName)
        {
            case "XLS":
                rgAllMamWithResults.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                rgAllMamWithResults.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                rgAllMamWithResults.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                rgAllMamWithResults.MasterTableView.ExportToWord();
                break;
        }
    }

    protected void rgAllMamWithResults_ExcelMLExportRowCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowCreatedArgs e)
    {
        if (e.RowType == Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowType.DataRow)
        {
            if (e.Row.Cells[0] != null && ((string)e.Row.Cells[0].Data.DataItem).Contains("U"))
            {
                e.Row.Cells[0].StyleValue = "MyCustomStyle";
            }
        }
    }

    protected void rgAllMamWithResults_ExcelMLExportStylesCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLStyleCreatedArgs e)
    {
        foreach (Telerik.Web.UI.GridExcelBuilder.StyleElement style in e.Styles)
        {
            if (style.Id == "headerStyle")
            {
                style.FontStyle.Bold = true;
                style.FontStyle.Color = System.Drawing.Color.Gainsboro;
                style.InteriorStyle.Color = System.Drawing.Color.Wheat;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "itemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.WhiteSmoke;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "alternatingItemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.LightGray;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
        }

        Telerik.Web.UI.GridExcelBuilder.StyleElement myStyle = new Telerik.Web.UI.GridExcelBuilder.StyleElement("MyCustomStyle");
        myStyle.FontStyle.Bold = true;
        myStyle.FontStyle.Italic = true;
        myStyle.InteriorStyle.Color = System.Drawing.Color.Gray;
        myStyle.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
        e.Styles.Add(myStyle);
    }

    public void ConfigureExport()
    {

        rgAllMamWithResults.ExportSettings.ExportOnlyData = true;
        rgAllMamWithResults.ExportSettings.IgnorePaging = true;
        rgAllMamWithResults.ExportSettings.OpenInNewWindow = true;
        rgAllMamWithResults.ExportSettings.HideStructureColumns = true;

        rgAllMamWithResults.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgAllMamWithResults.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");
    }
    #endregion

    #endregion

    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCCCR Ordered Pending Report";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion



}