﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;

public partial class Reports_BreastBiospies_Surgeries_Rpt : BasePage
{
    #region Member Variables

    private string _userId;
    bool isExport = false;
    private Reports r;

    private bool isPdfExport;
    public bool IsPDFExport
    {
        get
        {
            if (ViewState["IsPDFExport"] != null)
            {
                return (bool)ViewState["IsPDFExport"];
            }
            else
            {
                return false;
            }
        }

        set
        {
            isPdfExport = value;
            ViewState["IsPDFExport"] = value;
        }
    }

    #endregion

    /// <summary>
    /// Default Page_Load Method
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "<a href=\"Dashboard.aspx\" title=\"Navigate to Reports Dashboard\" style=\"color:#FFFFFF;\">Reports</a> > Breast Biopsies / Surgeries";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;

        try
        {
            //set the user ID variable
            _userId = _user.UserId.ToString();
            r = new Reports(_userId);

            if (!IsPostBack)
            {
                //set date
                rdpStartDate.SelectedDate = DateTime.Today.AddYears(-1);
                rdpEndDate.SelectedDate = DateTime.Today;

                rgBreastBiopsiesSurgeries.DataSource = "";
                rgBreastBiopsiesSurgeries.DataBind();

                //Fill the facilities listbox
                FillFACs();

                // Fill the Race list
                FillRaces();
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #region Private Methods

    /// <summary>
    /// Perform actual search. Call stored procedure with parameters.
    /// </summary>
    private void FillReportGrid()
    {
        PatientData pd = new PatientData();

        try
        {
            if (rcbFac.SelectedItem != null)
            {
                //get the report data
                string searchPatName = String.IsNullOrEmpty(rtbPatientName.Text) ? null : rtbPatientName.Text;
                string searchProviderName = String.IsNullOrEmpty(rtbProviderName.Text) ? null : rtbProviderName.Text;

                string ageRestrictString = "";
                ageRestrictString = (String.IsNullOrEmpty(rddlAgeRestriction.SelectedValue) ? null : rddlAgeRestriction.SelectedValue);

                string searchGender = null;
                if (String.IsNullOrEmpty(rlbGender.SelectedValue) || rlbGender.SelectedValue == "All")
                {
                    searchGender = null;
                }
                else
                {
                    searchGender = rlbGender.SelectedValue;
                }

                string searchReportType = null;
                if (String.IsNullOrEmpty(rddlReportType.SelectedValue) || rddlReportType.SelectedValue == "All")
                {
                    searchReportType = null;
                }
                else
                {
                    searchReportType = rddlReportType.SelectedValue;
                }

                string raceRestrictString = (rcbRace.SelectedValue == "All") ? null : rcbRace.SelectedValue;

                DateTime tempStartDate = (DateTime)rdpStartDate.SelectedDate;
                DateTime tempEndDate = (DateTime)rdpEndDate.SelectedDate;

                DataTable dt = pd.GetBreastBiopsiesSurgeries(rcbFac.SelectedValue, tempStartDate.ToShortDateString(), tempEndDate.ToShortDateString(), searchPatName, ageRestrictString, searchGender, searchReportType, searchProviderName, raceRestrictString);

                //bind the data to the grid
                rgBreastBiopsiesSurgeries.DataSource = dt;
                return;
            }
            //if no selected facility
            rgBreastBiopsiesSurgeries.DataSource = "";
        }
        catch (Exception ex)
        {
            //Logging.WriteLogToFile(_userId, ex);

            //if error
            rgBreastBiopsiesSurgeries.DataSource = "";
        }
    }

    /// <summary>
    /// Fills the facility drop down with the facilities the user has access to see.
    /// </summary>
    private void FillFACs()
    {
        try
        {
            //get the user's facilities and populate listboxs
            if (r.GetFacilitiesByUserId())
            {
                // Station drop down clear existing items

                rcbFac.Items.Clear();
                rcbFac.EmptyMessage = "Select a Station";

                // VISN drop down clear existing items

                rcbVisn.Items.Clear();
                rcbVisn.EmptyMessage = "Select a VISN";

                System.Data.DataTable tVisns = new DataTable();

                SetupVisnList(tVisns);

                DataView vw = new DataView(tVisns);
                vw.Sort = "[visnId] asc";

                rcbVisn.DataSource = vw;
                rcbVisn.DataTextField = "visnText";
                rcbVisn.DataValueField = "visnId";
                rcbVisn.DataBind();

                // If there's only one option, select it for them
                if (rcbVisn.Items.Count == 1)
                {
                    rcbVisn.SelectedIndex = 0;
                    rcbVisn.Enabled = false;
                    ProcessVisnSelection();
                }
                else if (rcbVisn.Items.Count == 0)
                {
                    rcbVisn.EmptyMessage = "You do not have access to any VISNs to select";
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    /// <summary>
    /// Fills the dropdown list for race filters.
    /// </summary>
    private void FillRaces()
    {
        rcbRace.Items.Clear();
        DataTable tempDataTable = r.GetDistinctPatientRaces();
        DataRow dr = tempDataTable.NewRow();
        dr["RACE"] = "All";
        tempDataTable.Rows.Add(dr);

        DataView vw = new DataView(tempDataTable);
        vw.Sort = "[RACE] asc";

        rcbRace.DataSource = vw;
        rcbRace.DataTextField = "RACE";
        rcbRace.DataValueField = "RACE";
        rcbRace.DataBind();
    }

    /// <summary>
    /// Populates VISN list based on the facilities that a user has access to
    /// </summary>
    /// <param name="tVisns"></param>
    private void SetupVisnList(System.Data.DataTable tVisns)
    {
        try
        {
            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "visnId";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "visnText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            tVisns.Columns.Add(idColumn);
            tVisns.Columns.Add(nameColumn);

            tVisns.PrimaryKey = new DataColumn[] { tVisns.Columns["visnId"] };

            DataRow drVisn;

            foreach (System.Data.DataRow dr in r.dtFac.Rows)
            {
                if (!tVisns.Rows.Contains(dr["visnId"]))
                {
                    drVisn = tVisns.NewRow();
                    drVisn["visnId"] = dr["visnId"];
                    drVisn["visnText"] = dr["visnText"];

                    tVisns.Rows.Add(drVisn);
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #endregion

    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCR Breast Biopsies / Surgeries Report";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion

    #region Grid Methods

    protected void rgBreastBiopsiesSurgeries_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        FillReportGrid();
    }

    protected void rgBreastBiopsiesSurgeries_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        try
        {
            //if (e.CommandName == RadGrid.FilterCommandName)
            //{
            //    Pair filterPair = (Pair)e.CommandArgument;

            //    switch (filterPair.Second.ToString())
            //    {
            //        case "date_of_last_mammogram":
            //            this.startDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("FromDatePicker") as RadDatePicker).SelectedDate;
            //            this.endDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("ToDatePicker") as RadDatePicker).SelectedDate;
            //            break;
            //        default:
            //            break;
            //    }
            //}
            //if (e.CommandName == "Reset")
            //{
            //    foreach (GridColumn column in rgBreastBiopsiesSurgeries.MasterTableView.OwnerGrid.Columns)
            //    {
            //        column.CurrentFilterFunction = GridKnownFunction.NoFilter;
            //        column.CurrentFilterValue = string.Empty;
            //    }
            //    rgBreastBiopsiesSurgeries.MasterTableView.FilterExpression = "";
            //    rgBreastBiopsiesSurgeries.Rebind();
            //}
        }
        catch (Exception ex)
        {
            //Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void rgBreastBiopsiesSurgeries_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
            e.Item.Visible = false;

        if (IsPDFExport && e.Item is Telerik.Web.UI.GridHeaderItem)
        {
            GridHeaderItem hItem = (GridHeaderItem)e.Item;
            hItem.Style["font-size"] = "12pt";
        }

        if (IsPDFExport && e.Item is Telerik.Web.UI.GridDataItem)
        {
            GridDataItem dataItem = (GridDataItem)e.Item;
            dataItem.Style["font-size"] = "9pt";
        }

        if (e.Item is GridHeaderItem && !isExport)
        {

            GridHeaderItem header = (GridHeaderItem)e.Item;

            //loops through all headercells, which is different than columns
            foreach (GridTableHeaderCell headerCell in header.Controls)
            {
                ImageButton img = new ImageButton();

                //if the headercell has controls, it is a column, not a columngroup
                if (headerCell.HasControls())
                {
                    //get the actual header text
                    string headerText = ((LiteralControl)headerCell.Controls[0]).Text;

                    //make sure it isn't the edit header
                    if (headerText != "&nbsp;")
                    {
                        try
                        {
                            img = setupImgButton(headerText, headerCell.HeaderID);

                            headerCell.Controls.Add(img);
                        }
                        catch (Exception ex)
                        {
                            Logging.WriteLogToFile(_userId, ex);
                        }

                        //loop through actual radgrid columns and compare to the header cells 
                        foreach (GridColumn col in rgBreastBiopsiesSurgeries.Columns)
                        {
                            //test to see if there is currently a sort expression and the header cell matches the column
                            if (rgBreastBiopsiesSurgeries.MasterTableView.SortExpressions.Count != 0
                                && (rgBreastBiopsiesSurgeries.MasterTableView.SortExpressions[0].FieldName == col.UniqueName ||
                                    rgBreastBiopsiesSurgeries.MasterTableView.SortExpressions[0].FieldName == col.SortExpression)
                                && headerText == col.HeaderText)
                            {
                                //check to see if the sort order isn't none
                                if (rgBreastBiopsiesSurgeries.MasterTableView.SortExpressions[0].SortOrder != GridSortOrder.None)
                                {
                                    //if it isn't none, remove the no sort image
                                    try
                                    {
                                        headerCell.Controls.Remove(img);
                                    }
                                    catch (Exception ex)
                                    {
                                        Logging.WriteLogToFile(_userId, ex);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    protected void rgBreastBiopsiesSurgeries_ItemDataBound(object sender, GridItemEventArgs e)
    {
        try
        {
            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");

                string[] fieldNames = { "TumorRegData", "Pathology" }; //"Biopsy_Result", "Pathology_Report", "brca_status","TumorRegistryData"};
                string reportName = "BB_";

                if (isExport)
                {
                    string columnName;
                    TableCell ctc;

                    // Inspect link fields and format accordingly for the output report

                    foreach (string columnRoot in fieldNames)
                    {
                        item = (GridDataItem)e.Item;
                        columnName = reportName + columnRoot + "_Report";
                        ctc = item[columnName];
                        Helpers.configureLinkForExport(ctc, columnRoot, reportName, "");
                    }

                    // Format cells
                    foreach (TableCell cell in e.Item.Cells)
                    {
                        cell.Style["mso-number-format"] = @"\@";
                    }
                }
                else // Not exporting, just displaying grid
                {
                    Label lbl;
                    string sData;
                    RadToolTip rtt;

                    // Inspect each link field and create links or appropriate message

                    foreach (string columnRoot in fieldNames)
                    {

                        lbl = (Label)item.FindControl("lbl" + reportName + columnRoot);
                        sData = ((System.Data.DataRowView)e.Item.DataItem)[columnRoot].ToString();
                        rtt = (RadToolTip)item.FindControl("rtt" + reportName + columnRoot);

                        Helpers.setupLink(lbl, sData, rtt, columnRoot, reportName);
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    ImageButton setupImgButton(string headerText, string headerID)
    {
        //create the sort button image
        ImageButton img = new ImageButton();

        img.ID = "Sort_" + headerID;
        img.AlternateText = "Sort " + headerText + " asc/desc";
        img.ImageUrl = "~/images/sort_none.gif";
        img.TabIndex = 25;
        img.ToolTip = img.AlternateText;

        switch (headerText)
        {
            case "PACT Team":
                img.AccessKey = "t";
                break;
            case "Provider Name":
                img.AccessKey = "p";
                break;
            case "Last Name, First":
                img.AccessKey = "n";
                break;
            case "Last 4":
                img.AccessKey = "s";
                break;
            case "Age":
                img.AccessKey = "a";
                break;
            case "Race":
                img.AccessKey = "r";
                break;
            case "Gender":
                img.AccessKey = "g";
                break;
            case "Patient Zip":
                img.AccessKey = "z";
                break;
            case "Date Performed":  // Mammogram
                img.AccessKey = "m";
                break;
            case "BI-RADS Code":
                img.AccessKey = "b";
                break;
            case "Procedure Location":
                img.AccessKey = "l";
                break;
            default:
                break;
        }

        return img;
    }

    #endregion

    #region Facility Dropdown Events

    protected void rcbVisn_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        btnRunReport.Enabled = false;

        ProcessVisnSelection();
    }

    protected void ProcessVisnSelection()
    {
        r.GetFacilitiesByUserId();

        // Station drop down clear existing items
        rcbFac.Items.Clear();
        rcbFac.Text = "";
        rcbFac.ClearSelection();

        if (rcbVisn.SelectedIndex > -1)
        {
            rcbFac.Enabled = true;

            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "sta3n";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "facText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            DataTable facs = new DataTable();
            facs.Columns.Add(idColumn);
            facs.Columns.Add(nameColumn);

            DataRow dr;

            foreach (DataRow drFac in r.dtFac.Rows)
            {
                if (drFac["visnId"].ToString() == rcbVisn.SelectedValue)
                {
                    dr = facs.NewRow();
                    dr["sta3n"] = drFac["sta3n"];
                    dr["facText"] = drFac["facText"];

                    facs.Rows.Add(dr);
                }
            }

            rcbFac.DataSource = facs;
            rcbFac.DataTextField = "facText";
            rcbFac.DataValueField = "sta3n";
            rcbFac.DataBind();

            // If there's only one option, select it for them
            if (rcbFac.Items.Count == 1)
            {
                rcbFac.SelectedIndex = 0;
                //rcbFac.Enabled = false;
                btnRunReport.Enabled = true;
            }
        }
        else
        {
            rcbFac.Enabled = false;
        }
    }

    protected void rcbFac_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            btnRunReport.Enabled = true;
        }
        else
        {
            btnRunReport.Enabled = false;
        }
    }

    #endregion

    #region GUI Event Methods

    /// <summary>
    /// Run report and call FillReportGrid
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnRunReport_Click(object sender, EventArgs e)
    {
        DateTime start = DateTime.Now;

        FillReportGrid();
        rgBreastBiopsiesSurgeries.DataBind();

        DateTime end = DateTime.Now;
        lblExecutionTime.Text = Math.Round((end - start).TotalSeconds, 2).ToString() + " seconds";
    }

    /// <summary>
    /// Removes all search criteria and clears grid.
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnClearReport_Click(object sender, EventArgs e)
    {
        // clear search fields
        //set date
        rdpStartDate.SelectedDate = DateTime.Today.AddYears(-1);
        rdpEndDate.SelectedDate = DateTime.Today;

        //chkShowLatest.Checked = true;

        //rlbBiRadsList.SelectedIndex = -1;

        rtbPatientName.Text = "";

        rlbGender.SelectedIndex = 0;

        //rtbProviderName.Text = "";

        FillFACs();
        btnRunReport.Enabled = false;

        rgBreastBiopsiesSurgeries.DataSource = "";
        rgBreastBiopsiesSurgeries.DataBind();

        lblExecutionTime.Text = "";
    }

    /// <summary>
    /// Export
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();
        switch (((Button)sender).CommandName)
        {
            case "XLS":
                IsPDFExport = false;
                rgBreastBiopsiesSurgeries.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                IsPDFExport = false;
                rgBreastBiopsiesSurgeries.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                IsPDFExport = true;
                rgBreastBiopsiesSurgeries.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                IsPDFExport = false;
                rgBreastBiopsiesSurgeries.MasterTableView.ExportToWord();
                break;
        }
    }

    /// <summary>
    /// Setup the Export
    /// </summary>
    protected void ConfigureExport()
    {

        rgBreastBiopsiesSurgeries.MasterTableView.AllowPaging = false;
        rgBreastBiopsiesSurgeries.Rebind(); 

        StringBuilder reportHeaderString = new StringBuilder();
        reportHeaderString.Append("<div style=\"width:100%; font-size: 15pt; clear:both; text-align:left;\">");
        reportHeaderString.Append("Breast Biopsies and Surgeries Report");
        reportHeaderString.Append("</div>");
        reportHeaderString.Append("<div style=\"width:100%; font-size: 12pt; clear:both; text-align:left;\">");
        reportHeaderString.Append("Exported:" + DateTime.Now.ToString() + " - Total Number of Records: " + rgBreastBiopsiesSurgeries.MasterTableView.Items.Count.ToString() + "<br />");
        reportHeaderString.Append("Filters: " + "<br />");
        reportHeaderString.Append("</div>");

        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.PageTitle = "Breast Biopsies and Surgeries Report";
        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.PageHeader.LeftCell.Text = "Exported:" + DateTime.Now.ToString();
        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.PageHeader.MiddleCell.Text = "Filters: ";
        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.PageHeader.RightCell.Text = "Total Number of Records: " + rgBreastBiopsiesSurgeries.MasterTableView.Items.Count.ToString();
        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.DefaultFontFamily = "Arial Unicode MS";
        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.ForceTextWrap = true;

        rgBreastBiopsiesSurgeries.MasterTableView.Caption = reportHeaderString.ToString();
        rgBreastBiopsiesSurgeries.Rebind(); 
        rgBreastBiopsiesSurgeries.ExportSettings.ExportOnlyData = true;
        rgBreastBiopsiesSurgeries.ExportSettings.IgnorePaging = true;
        rgBreastBiopsiesSurgeries.ExportSettings.OpenInNewWindow = true;
        rgBreastBiopsiesSurgeries.ExportSettings.HideStructureColumns = true;

        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgBreastBiopsiesSurgeries.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");

        foreach (GridColumn gc in rgBreastBiopsiesSurgeries.MasterTableView.Columns)
        {
            gc.ColumnGroupName = null;
        }

        foreach (GridColumn col in rgBreastBiopsiesSurgeries.MasterTableView.RenderColumns)
        {
            if (col.UniqueName.EndsWith("_Report"))
                col.Visible = true;
            else if (col.UniqueName.EndsWith("GUI") || col.UniqueName == "EditCommandColumn")
                col.Visible = false;
        }
        rgBreastBiopsiesSurgeries.Rebind();
    }

    #endregion
}