﻿using System;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;

public partial class BiRad : BasePage
{
    #region Intialize Variables
    private string _userId;
    bool isExport = false;
    #endregion

    #region Page Events
    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "Mammograms By Diagnosis Aggregate";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;

        _userId = _user.UserId.ToString();

        try
        {
            #region Set Date Params
            toDate.MaxDate = DateTime.Today;
            fromDate.MaxDate = DateTime.Today;
            #endregion

            if (!IsPostBack)
            {
                FillDivisionTree();

                //set date
                fromDate.SelectedDate = DateTime.Today.AddYears(-1);
                toDate.SelectedDate = DateTime.Today;
            }

            GridFilterMenu menu = rgAggregateData.FilterMenu;
            int i = 0;

            //loop through filter menu
            while (i < menu.Items.Count)
            {
                try
                {
                    //add tooltip and access key for 508
                    if (menu.Items[i] != null)
                    {
                        menu.Items[i].ToolTip = menu.Items[i].Text;
                        //symbols
                        int asciiChar = i + 41;
                        char charValue = Convert.ToChar(asciiChar);
                        menu.Items[i].AccessKey = charValue.ToString();
                    }
                }
                catch (Exception ex)
                {
                    Logging.WriteLogToFile(_userId, ex);
                }

                i += 1;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Private Methods

    private void CreateReport()
    {
        bool all = false;
        bool nat = false;
        string level1 = null;
        string level2 = null;
        string level3 = null;

        try
        {

            foreach (RadTreeNode rtn in rtvDivision.CheckedNodes)
            {
                switch (rtn.Level)
                {
                    case 0:
                        all = true;
                        break;
                    case 1:
                        level1 += rtn.Value + ",";
                        break;
                    case 2:
                        level2 += rtn.Value + ",";
                        break;
                    case 3:
                        level3 += rtn.Value + ",";
                        break;
                }
            }

            string visnList = null;
            string facList = null;
            string pacList = null;

            if (level1 != null)
            {
                string[] l1 = level1.Split(',');

                foreach (string s in l1)
                {
                    if (s == "NAT")
                    {
                        nat = true;
                    }
                }
                //remove NAT from VISN list
                visnList = level1.Trim().Substring(0, level1.Length - 1).Replace("NAT,", "").Replace("NAT", "");
            }
            if (level2 != null)
            {
                facList = level2.Trim().Substring(0, level2.Length - 1);
            }
            if (level3 != null)
            {
                pacList = level3.Trim().Substring(0, level3.Length - 1);
            }

            Aggregate agg = new Aggregate();

            //DataTable dt = agg.GetAllMamByDiag(all, nat, visnList, facList, pacList, fromDate.DbSelectedDate.ToString(), toDate.DbSelectedDate.ToString());
            DataTable dt = GetMockUpData();

            if (dt != null && rtvDivision.CheckedNodes.Count > 0)
            {
                rgAggregateData.DataSource = dt;

                if (rblReportType.SelectedIndex != 0 && rtvDivision.CheckedNodes.Count > 0 && rtvDivision.CheckedNodes.Count < 7)
                {
                    LoadCharts(dt);
                }
                else
                {
                    rcBar.Visible = false;
                    rcPie1.Visible = false;
                    rcPie2.Visible = false;
                }
            }
            else
            {
                rgAggregateData.DataSource = "";
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private DataTable GetMockUpData()
    {
        DataTable dt = new DataTable();
        dt.Columns.Add("division");
        dt.Columns.Add("0");
        dt.Columns.Add("0P");
        dt.Columns.Add("1");
        dt.Columns.Add("1P");
        dt.Columns.Add("2");
        dt.Columns.Add("2P");
        dt.Columns.Add("3");
        dt.Columns.Add("3P");
        dt.Columns.Add("4");
        dt.Columns.Add("4P");
        dt.Columns.Add("5");
        dt.Columns.Add("5P");
        dt.Columns.Add("6");
        dt.Columns.Add("6P");

        dt.Rows.Add("National", "10000", "10", "100000", "65", "7500", "5", "8000", "6", "PORT", "4", "7500", "5", "7500", "5");
        dt.Rows.Add("VISN 1", "1500", "10", "10500", "65", "750", "5", "800", "6", "700", "4", "750", "5", "750", "5");
        dt.Rows.Add("VISN 2", "1500", "10", "10500", "65", "750", "5", "800", "6", "700", "4", "750", "5", "750", "5");
        dt.Rows.Add("VISN 3", "1500", "10", "10500", "65", "750", "5", "800", "6", "700", "4", "750", "5", "750", "5");
        dt.Rows.Add("VISN 4", "1500", "10", "10500", "65", "750", "5", "800", "6", "700", "4", "750", "5", "750", "5");
        dt.Rows.Add("FAC1", "150", "10", "1050", "65", "75", "5", "80", "6", "70", "4", "75", "5", "75", "5");
        dt.Rows.Add("PAC1", "15", "10", "105", "65", "8", "5", "8", "6", "7", "4", "7", "5", "7", "5");

        return dt;
    }

    public string FormatData(string field)
    {
        return Eval(field).ToString() + " (" + Eval(field + "p").ToString() + "%)";
    }

    private void CreatePieChart(DataTable dt, int row, RadHtmlChart rc)
    {
        //rc.PlotArea.Series.Clear();
        //PieSeries ps1 = new PieSeries();
        //ps1.Name = "PieSeries" + row.ToString();
        //ps1.LabelsAppearance.Position = Telerik.Web.UI.HtmlChart.PieLabelsPosition.Circle;
        //ps1.LabelsAppearance.DataFormatString = "{0} %";
        //ps1.TooltipsAppearance.DataFormatString = "{0} %";

        //DataTable dtPie1 = new DataTable();

        //try
        //{
        //    string div = dt.Rows[row][0].ToString();
        //    dtPie1 = dt.Select("Division='" + div + "'", "").CopyToDataTable();


        //    SeriesItem si0 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad0p"]));
        //    si0.BackgroundColor = Color.Yellow;
        //    si0.Name = "0";
        //    SeriesItem si1 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad1p"]));
        //    si1.BackgroundColor = Color.Blue;
        //    si1.Name = "1: Negative";
        //    SeriesItem si2 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad2p"]));
        //    si2.BackgroundColor = Color.Green;
        //    si2.Name = "2: Benign finding(s)";
        //    SeriesItem si3 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad3p"]));
        //    si3.BackgroundColor = Color.Purple;
        //    si3.Name = "3: Probably benign";
        //    SeriesItem si4 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad4p"]));
        //    si4.BackgroundColor = Color.Orange;
        //    si4.Name = "4: Suspicious abnormality";
        //    SeriesItem si5 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad5p"]));
        //    si5.BackgroundColor = Color.Red;
        //    si5.Name = "5: Highly suggestive of malignancy";
        //    SeriesItem si6 = new SeriesItem(Convert.ToDecimal(dtPie1.Rows[0]["birad6p"]));
        //    si6.BackgroundColor = Color.Black;
        //    si6.Name = "6: Known biopsy – proven malignancy";


        //    ps1.Items.Add(si0);
        //    ps1.Items.Add(si1);
        //    ps1.Items.Add(si2);
        //    ps1.Items.Add(si3);
        //    ps1.Items.Add(si4);
        //    ps1.Items.Add(si5);
        //    ps1.Items.Add(si6);

        //    rc.ChartTitle.Text = "BI-RADS for Percentages for " + rtvDivision.CheckedNodes[row].Text;
        //    rc.PlotArea.Series.Add(ps1);

        //}
        //catch (Exception ex)
        //{
        //    Logging.WriteLogToFile(_userId, ex);
        //}
    }

    private void LoadCharts(DataTable dt)
    {
        try
        {
            if (rblReportType.SelectedIndex == 1)
            {
                if (rtvDivision.CheckedNodes.Count > 0 && rtvDivision.CheckedNodes.Count < 3)
                {

                    CreatePieChart(dt, 0, rcPie1);

                    if (rtvDivision.CheckedNodes.Count == 2)
                    {
                        CreatePieChart(dt, 1, rcPie2);
                    }
                }
            }
            else if (rblReportType.SelectedIndex == 2)
            {
                if (rtvDivision.CheckedNodes.Count > 0 && rtvDivision.CheckedNodes.Count < 7)
                {
                    rcBar.DataSource = dt;
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    public void FillDivisionTree()
    {
        try
        {
            Reports r = new Reports(_userId);

            DataSet ds = new DataSet();

            DataTable dtVISN = r.GetVISNs().Copy();
            dtVISN.TableName = "VISNs";

            DataTable dtFac = r.GetFacs().Copy();
            dtFac.TableName = "Facilities";

            DataTable dtPAC = r.GetPACs().Copy();
            dtPAC.TableName = "PACs";

            ds.Tables.Add(dtVISN);
            ds.Tables.Add(dtFac);
            ds.Tables.Add(dtPAC);

            ds.Relations.Add("VISN_Facilities", ds.Tables[0].Columns["visnId"], ds.Tables[1].Columns["visn_fk"]);
            ds.Relations.Add("FAC_PACs", ds.Tables[1].Columns["facId"], ds.Tables[2].Columns["fac_fk"]);

            RadTreeNode all = new RadTreeNode("All", "ALL");
            rtvDivision.Nodes.Add(all);
            all.Expanded = true;
            RadTreeNode nat = new RadTreeNode("National", "NAT");
            all.Nodes.Add(nat);
            //prop.Selected = true;

            foreach (DataRow visnRow in ds.Tables[0].Rows)
            {
                RadTreeNode visnNode = new RadTreeNode(visnRow["visnText"].ToString());
                visnNode.Value = visnRow["visnId"].ToString();

                all.Nodes.Add(visnNode);

                //RadTreeNode fac = new RadTreeNode("Facilities");
                //visnNode.Nodes.Add(fac);

                foreach (DataRow facRow in visnRow.GetChildRows("VISN_Facilities"))
                {
                    RadTreeNode facNode = new RadTreeNode(facRow["facText"].ToString());
                    facNode.Value = facRow["facId"].ToString();
                    visnNode.Nodes.Add(facNode);
                    foreach (DataRow pacRow in facRow.GetChildRows("FAC_PACs"))
                    {
                        RadTreeNode pacNode = new RadTreeNode(pacRow["pacText"].ToString());
                        pacNode.Value = pacRow["pacId"].ToString();
                        facNode.Nodes.Add(pacNode);
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }

        //rtvDivision.ExpandAllNodes();
    }

    private void CountDivisions()
    {
        try
        {
            if (rtvDivision.CheckedNodes.Count > 0)
            {
                btnCreateReport.Enabled = true;
                if (rtvDivision.CheckedNodes[0].Value == "ALL")
                {
                    rblReportType.Items[1].Enabled = false;
                    rblReportType.Items[2].Enabled = false;
                    foreach (RadTreeNode rtn in rtvDivision.GetAllNodes())
                    {
                        if (rtn.Level != 0)
                        {
                            rtn.Enabled = false;
                            rtn.Checked = false;
                            rtn.Selected = false;
                        }
                    }
                }
                else
                {
                    rblReportType.Items[1].Enabled = true;
                    rblReportType.Items[2].Enabled = true;

                    foreach (RadTreeNode rtn in rtvDivision.GetAllNodes())
                    {
                        rtn.Enabled = true;
                    }

                    if (rtvDivision.CheckedNodes.Count > 2)
                    {
                        rblReportType.Items[1].Enabled = false;
                    }
                    else
                    {
                        rblReportType.Items[1].Enabled = true;
                    }
                    if (rtvDivision.CheckedNodes.Count > 6)
                    {
                        rblReportType.Items[2].Enabled = false;
                    }
                    else
                    {
                        rblReportType.Items[2].Enabled = true;
                    }
                }
            }
            else
            {
                btnCreateReport.Enabled = false;
                rblReportType.Items[1].Enabled = true;
                rblReportType.Items[2].Enabled = true;

                foreach (RadTreeNode rtn in rtvDivision.GetAllNodes())
                {
                    rtn.Enabled = true;
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #endregion

    #region Button Events
    protected void btnGetReport_Click(object sender, EventArgs e)
    {
        CreateReport();
        rgAggregateData.DataBind();

        try
        {
            switch (rblReportType.SelectedIndex)
            {
                case 0:
                    rcPie1.Visible = false;
                    rcBar.Visible = false;
                    break;
                case 1:
                    rcPie1.Visible = true;
                    if (rtvDivision.CheckedNodes.Count == 2)
                    {
                        rcPie2.Visible = true;
                    }
                    else
                    {
                        rcPie2.Visible = false;
                    }
                    rcBar.Visible = false;
                    break;
                case 2:
                    rcBar.Visible = true;
                    rcPie1.Visible = false;
                    rcPie2.Visible = false;
                    break;
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Treeview Events

    protected void rtvDivision_NodeClick(object sender, RadTreeNodeEventArgs e)
    {
        try
        {
            if (e.Node.Selected)
            {
                e.Node.Checked = true;
            }
            else
            {
                e.Node.Checked = false;
            }

            CountDivisions();

            rblReportType.SelectedIndex = 0;
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void rtvDivision_NodeCheck(object sender, RadTreeNodeEventArgs e)
    {
        try
        {
            if (e.Node.Checked)
            {
                e.Node.Selected = true;
            }
            else
            {
                e.Node.Selected = false;
            }

            CountDivisions();

            rblReportType.SelectedIndex = 0;
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }



    #endregion

    #region Report Grid Events

    protected void rgAggregateData_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        if (rtvDivision.CheckedNodes.Count > 0)
        {
            CreateReport();
        }
    }

    protected void rgAggregateData_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        //Used for drill downs if needed
        //On row click, gather the row's info and set the session for selecteduser
        if ((e.CommandName == "RowClick" || e.CommandName == "Edit") && e.Item is GridDataItem)
        {
            //insert logic here
            //****
            //cancels edit form
            e.Canceled = true;
        }
    }

    protected void rgAggregateData_ItemDataBound(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridDataItem)
        {
            //GridDataItem item = (GridDataItem)e.Item;
            //if (item["Division"].Text == "My PAC Team")
            //{
            //    item["birad0"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=0'>" + item["birad0"].Text + "</a>";
            //    item["birad1"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=1'>" + item["birad1"].Text + "</a>";
            //    item["birad2"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=2'>" + item["birad2"].Text + "</a>";
            //    item["birad3"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=3'>" + item["birad3"].Text + "</a>";
            //    item["birad4"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=4'>" + item["birad4"].Text + "</a>";
            //    item["birad5"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=5'>" + item["birad5"].Text + "</a>";
            //    item["birad6"].Text = "<a href='http://localhost:32919/BCCCR_UserInterface/demo.aspx?birad=6'>" + item["birad6"].Text + "</a>";

            //}

            //if (rtvDivision.CheckedNodes.Count > 0)
            //{
            //    if (rtvDivision.CheckedNodes[0].Value != "ALL")
            //    {
            //        foreach (RadTreeNode rtn in rtvDivision.CheckedNodes)
            //        {
            //            if (item["Division"].Text == rtn.Text)
            //            {
            //                item.Visible = true;
            //            }
            //            else
            //            {
            //                item.Visible = false;
            //            }
            //        }

            //    }
            //}


        }

        try
        {
            if (e.Item is GridHeaderItem)
            {
                //add access keys to header items for 508
                GridHeaderItem hi = (GridHeaderItem)e.Item;

                //LinkButton pn = (LinkButton)hi["Phys_Name"].Controls[0];
                //pn.AccessKey = "p";

                //LinkButton ln = (LinkButton)hi["Last_Name"].Controls[0];
                //ln.AccessKey = "n";

                //LinkButton fn = (LinkButton)hi["First_Name"].Controls[0];
                //fn.AccessKey = "f";

                //LinkButton ssn = (LinkButton)hi["SSN"].Controls[0];
                //ssn.AccessKey = "u";

                ////add tableheader scope for 508
                //TableCell tcFirstName = hi.Cells[7];
                //tcFirstName.Attributes.Add("scope", "col");
            }

            if (e.Item is GridFilteringItem)
            {
                //Add tooltip to SSN column for 508
                GridFilteringItem filterItem = (GridFilteringItem)e.Item;
                //have to do this here because can't in custom column on front end
                //***index may change***
                //filterItem.Cells[4].ToolTip = "Filter Textbox for SSN";

                ////set tooltips for each filter button for 508
                //Button btnPN = (Button)filterItem["Phys_Name"].Controls[1];
                //btnPN.ToolTip = "Filter Physician Name";

                //Button btnLN = (Button)filterItem["Last_Name"].Controls[1];
                //btnLN.ToolTip = "Filter Last Name";

                //Button btnFN = (Button)filterItem["First_Name"].Controls[1];
                //btnFN.ToolTip = "Filter First Name";

                //Button btnSSN = (Button)filterItem["SSN"].Controls[1];
                //btnSSN.ToolTip = "Filter SSN";
            }

            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }

    }

    protected void rgAggregateData_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
            e.Item.Visible = false;
    }

    #region Export

    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();
        switch (((Button)sender).CommandName)
        {
            case "XLS":
                rgAggregateData.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                rgAggregateData.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                rgAggregateData.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                rgAggregateData.MasterTableView.ExportToWord();
                break;
        }
    }

    protected void rgAggregateData_ExcelMLExportRowCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowCreatedArgs e)
    {
        if (e.RowType == Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowType.DataRow)
        {
            if (e.Row.Cells[0] != null && ((string)e.Row.Cells[0].Data.DataItem).Contains("U"))
            {
                e.Row.Cells[0].StyleValue = "MyCustomStyle";
            }
        }
    }

    protected void rgAggregateData_ExcelMLExportStylesCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLStyleCreatedArgs e)
    {
        foreach (Telerik.Web.UI.GridExcelBuilder.StyleElement style in e.Styles)
        {
            if (style.Id == "headerStyle")
            {
                style.FontStyle.Bold = true;
                style.FontStyle.Color = System.Drawing.Color.Gainsboro;
                style.InteriorStyle.Color = System.Drawing.Color.Wheat;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "itemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.WhiteSmoke;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "alternatingItemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.LightGray;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
        }

        Telerik.Web.UI.GridExcelBuilder.StyleElement myStyle = new Telerik.Web.UI.GridExcelBuilder.StyleElement("MyCustomStyle");
        myStyle.FontStyle.Bold = true;
        myStyle.FontStyle.Italic = true;
        myStyle.InteriorStyle.Color = System.Drawing.Color.Gray;
        myStyle.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
        e.Styles.Add(myStyle);
    }

    public void ConfigureExport()
    {

        rgAggregateData.ExportSettings.ExportOnlyData = true;
        rgAggregateData.ExportSettings.IgnorePaging = true;
        rgAggregateData.ExportSettings.OpenInNewWindow = true;
        rgAggregateData.ExportSettings.HideStructureColumns = true;

        rgAggregateData.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgAggregateData.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");
    }
    #endregion

    #endregion

    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCCCR Aggregate Data Template";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion
}