﻿using System;
using System.Data;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Telerik.Web.UI;
using VeteransAffairs.Registries.BusinessManager;
using CustomFilter;

public partial class MamByDiag : BasePage
{

    #region Intialize Variables
    private string _userId;
    bool isExport = false;
    bool isEdit = false;
    private Reports r;
    #endregion

    #region Page Events

    protected void rgMamByDiag_PreRender(object sender, System.EventArgs e)
    {
        if (this.rgMamByDiag.MasterTableView.Items.Count > 0 && isEdit == false)
        {
            for (int i = 0; i < this.rgMamByDiag.MasterTableView.Items.Count; i++)
            {
                if (this.rgMamByDiag.MasterTableView.Items[i].Edit == true)
                    this.rgMamByDiag.MasterTableView.Items[i].Edit = false;
            }

            this.rgMamByDiag.MasterTableView.Rebind();

            foreach (GridNoRecordsItem i in rgMamByDiag.MasterTableView.GetItems(GridItemType.NoRecordsItem))
            {
                if (i.ItemType == GridItemType.Item)
                {
                    int j = 1;
                    j++;
                }
            }
        }
    }

    protected void Page_Load(object sender, EventArgs e)
    {
        LabelBreadCrumb.Text = "All Mammograms by Diagnosis";

        UserAccountManager _user = (UserAccountManager)HttpContext.Current.User;

        try
        {
            //set the user ID variable
            _userId = _user.UserId.ToString();
            r = new Reports(_userId);

            #region Set Date Params
            fromDate.MaxDate = DateTime.Today;
            toDate.MaxDate = DateTime.Today;
            #endregion

            if (!IsPostBack)
            {
                //Fill the facilities listbox
                FillFACs();

                if (Request.QueryString["birad"] != null)
                {
                    FillReportGrid();
                    rgMamByDiag.MasterTableView.FilterExpression = "BiRadCode=" + Request.QueryString["birad"].ToString();
                    rgMamByDiag.Rebind();
                }

                //set date
                fromDate.SelectedDate = DateTime.Today.AddYears(-1);
                toDate.SelectedDate = DateTime.Today;
            }

            #region Filter menu modification
            GridFilterMenu menu = rgMamByDiag.FilterMenu;
            int i = 0;

            //loop through filter menu
            while (i < menu.Items.Count)
            {
                try
                {
                    //add tooltip and access key for 508
                    if (menu.Items[i] != null)
                    {
                        menu.Items[i].ToolTip = menu.Items[i].Text;
                        //symbols
                        int asciiChar = i + 41;
                        char charValue = Convert.ToChar(asciiChar);
                        menu.Items[i].AccessKey = charValue.ToString();
                    }
                }
                catch (Exception ex)
                {
                    Logging.WriteLogToFile(_userId, ex);
                }

                i += 1;
            }
            #endregion
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }
    #endregion

    #region Private Methods
    private void FillFACs()
    {
        try
        {
            //get the user's facilities and populate listboxs
            if (r.GetFacilitiesByUserId())
            {
                // VISN drop down clear existing items

                rcbVisn.Items.Clear();
                rcbVisn.EmptyMessage = "Select a VISN";

                System.Data.DataTable tVisns = new DataTable();

                SetupVisnList(tVisns);

                DataView vw = new DataView(tVisns);
                vw.Sort = "[visnId] asc";

                rcbVisn.DataSource = vw;
                rcbVisn.DataTextField = "visnText";
                rcbVisn.DataValueField = "visnId";
                rcbVisn.DataBind();

                // Station drop down clear existing items

                rcbFac.Items.Clear();
                rcbFac.EmptyMessage = "Select a Station";
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private void SetupVisnList(System.Data.DataTable tVisns)
    {
        try
        {
            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "visnId";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "visnText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            tVisns.Columns.Add(idColumn);
            tVisns.Columns.Add(nameColumn);

            tVisns.PrimaryKey = new DataColumn[] { tVisns.Columns["visnId"] };

            DataRow drVisn;

            foreach (System.Data.DataRow dr in r.dtFac.Rows)
            {
                if (!tVisns.Rows.Contains(dr["visnId"]))
                {
                    drVisn = tVisns.NewRow();
                    drVisn["visnId"] = dr["visnId"];
                    drVisn["visnText"] = dr["visnText"];

                    tVisns.Rows.Add(drVisn);
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    private DataTable GetMockData()
    {
        DataTable dt = new DataTable();
        dt.Columns.Add("id");
        dt.Columns.Add("PACTeam");
        dt.Columns.Add("OrderingPhysician");
        dt.Columns.Add("PatientLastName");
        dt.Columns.Add("PatientFirstName");
        dt.Columns.Add("PatientSSN");
        dt.Columns.Add("BiRadCode");
        dt.Columns.Add("DateOfLastMammogram");
        dt.Columns.Add("DateOrdered");
        dt.Columns.Add("DateScheduled");

        dt.Rows.Add("1", "PACTeam1", "Brown, John", "Martin", "Mary", "***-**-1234", "0", "1/26/2011", "1/13/2012", "1/15/2012");
        dt.Rows.Add("2", "PACTeam1", "Brown, John", "Sampson", "Jessica", "***-**-4567", "1", "2/26/2011", "2/13/2012", "2/15/2012");
        dt.Rows.Add("3", "PACTeam2", "Brown, John", "Davis", "Beth", "***-**-7890", "2", "3/26/2011", "3/13/2012", "3/15/2012");
        dt.Rows.Add("4", "PACTeam1", "Doe, Jane", "Smith", "Alexandria", "***-**-0123", "2", "4/26/2011", "4/13/2012", "4/15/2012");
        dt.Rows.Add("5", "PACTeam4", "Does, Jane", "Hawkins", "Andrea", "***-**-3456", "3", "5/26/2011", "5/13/2012", "5/15/2012");
        dt.Rows.Add("6", "PACTeam1", "Brown, John", "Donald", "Lisa", "***-**-6789", "5", "6/26/2011", "6/13/2012", "6/15/2012");
        dt.Rows.Add("7", "PACTeam6", "Martinez, Sue", "Davis", "Lauren", "***-**-9012", "4", "7/26/2011", "7/13/2012", "7/15/2012");
        dt.Rows.Add("8", "PACTeam1", "Doe, Jane", "Smithfield", "Alexa", "***-**-2345", "0", "8/26/2011", "8/13/2012", "8/15/2012");
        dt.Rows.Add("9", "PACTeam7", "Martinez, Sue", "Garber", "Lauren", "***-**-5678", "5", "9/26/2011", "9/13/2012", "9/15/2012");

        return dt;
    }

    private void FillReportGrid()
    {
        PatientData pd = new PatientData();

        try
        {
            //if (rcbFac.SelectedItem != null)
            //{
            //get the report data
            DataTable dt = pd.GetMamByDiag(rcbFac.SelectedItem.Value, fromDate.DbSelectedDate.ToString(), toDate.DbSelectedDate.ToString());
            //DataTable dt = GetMockData();
          
            //populates the dropdown filters
            PopulateReportFilters(dt);

            //bind the data to the grid
            rgMamByDiag.DataSource = dt;
            //return;
            //}
            //if no selected facility

        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);

            //if no selected facility
            rgMamByDiag.DataSource = "";
        }
    }

    //populates the dropdown filters for the respective columns
    private void PopulateReportFilters(DataTable dt)
    {
        DataTable filteredDt = Helpers.GetFilteredDataSource(rgMamByDiag, dt);

        DataSetHelper dsHelper;

        dsHelper = new DataSetHelper();

        DataTable dtPAC = dsHelper.SelectDistinct("DistinctPAC", filteredDt, "team_name");
        DataTable dtPhys = dsHelper.SelectDistinct("DistinctPhys", filteredDt, "primary_care_physician");
        DataTable dtRace = dsHelper.SelectDistinct("DistinctRace", filteredDt, "race");
        DataTable dtGender = dsHelper.SelectDistinct("DistinctGender", filteredDt, "gender");
        DataTable dtBiRad = dsHelper.SelectDistinct("DistinctBiRad", filteredDt, "BiRad_Code");

        try
        {
            foreach (GridColumn col in rgMamByDiag.MasterTableView.Columns)
            {
                if (col.ColumnType == "CustomFilteringColumn")
                {
                    CustomFilteringColumn column = (CustomFilteringColumn)col;

                    if (column.DataField == "team_name")
                    {
                        (column).ListDataSource = dtPAC;
                    }
                    else if (column.DataField == "primary_care_physician")
                    {
                        (column).ListDataSource = dtPhys;
                    }
                    else if (column.DataField == "BiRad_Code")
                    {
                        (column).ListDataSource = dtBiRad;
                    }
                    else if (column.DataField == "race")
                    {
                        (column).ListDataSource = dtRace;
                    }
                    else if (column.DataField == "gender")
                    {
                        (column).ListDataSource = dtGender;
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    protected void btnReport_Click(object sender, EventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            FillReportGrid();
            rgMamByDiag.DataBind();
        }
    }

    #endregion

    #region Facility Dropdown Events
    protected void rcbVisn_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        r.GetFacilitiesByUserId();

        // Station drop down clear existing items
        rcbFac.Items.Clear();
        rcbFac.Text = "";
        rcbFac.ClearSelection();

        if (rcbVisn.SelectedIndex > -1)
        {
            rcbFac.Enabled = true;

            DataColumn idColumn = new DataColumn();
            idColumn = new DataColumn();
            idColumn.DataType = System.Type.GetType("System.Int32");
            idColumn.ColumnName = "facId";
            idColumn.ReadOnly = true;
            idColumn.Unique = true;

            DataColumn nameColumn = new DataColumn();
            nameColumn = new DataColumn();
            nameColumn.DataType = System.Type.GetType("System.String");
            nameColumn.ColumnName = "facText";
            nameColumn.ReadOnly = true;
            nameColumn.Unique = true;

            DataTable facs = new DataTable();
            facs.Columns.Add(idColumn);
            facs.Columns.Add(nameColumn);

            DataRow dr;

            foreach (DataRow drFac in r.dtFac.Rows)
            {
                if (drFac["visnId"].ToString() == rcbVisn.SelectedValue)
                {
                    dr = facs.NewRow();
                    dr["facId"] = drFac["facId"];
                    dr["facText"] = drFac["facText"];

                    facs.Rows.Add(dr);
                }
            }

            rcbFac.DataSource = facs;
            rcbFac.DataTextField = "facText";
            rcbFac.DataValueField = "facId";
            rcbFac.DataBind();
        }
        else
        {
            rcbFac.Enabled = false;
        }
    }
    
    protected void rcbFac_SelectedIndexChanged(object sender, RadComboBoxSelectedIndexChangedEventArgs e)
    {
        if (rcbFac.SelectedIndex > -1)
        {
            btnRunReport.Enabled = true;
        }
        else
        {
            btnRunReport.Enabled = false;
        }
    }
    #endregion

    #region Report Grid Events

    protected void rgMamByDiag_NeedDataSource(object source, Telerik.Web.UI.GridNeedDataSourceEventArgs e)
    {
        FillReportGrid();
    }

    protected void rgMamByDiag_ItemCommand(object source, Telerik.Web.UI.GridCommandEventArgs e)
    {
        try
        {
            if (e.CommandName == RadGrid.EditCommandName)
            {
                isEdit = true;
            }
            else
            {
                isEdit = false;
            }
            //Used for drill downs if needed
            //On row click, gather the row's info and set the session for selecteduser
            //if ((e.CommandName == "RowClick" || e.CommandName == "Edit") && e.Item is GridDataItem)
            //{
            //    //insert logic here
            //    //****
            //    //cancels edit form
            //    e.Canceled = true;
            //}
            if (e.CommandName == RadGrid.FilterCommandName)
            {
                Pair filterPair = (Pair)e.CommandArgument;

                switch (filterPair.Second.ToString())
                {
                    case "DateScheduled":
                        this.startDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("FromOrderDatePicker") as RadDatePicker).SelectedDate;
                        this.endDate = ((e.Item as GridFilteringItem)[filterPair.Second.ToString()].FindControl("ToOrderDatePicker") as RadDatePicker).SelectedDate;
                        break;
                    default:
                        break;
                }
            }
            if (e.CommandName == "Reset")
            {
                foreach (GridColumn column in rgMamByDiag.MasterTableView.OwnerGrid.Columns)
                {
                    column.CurrentFilterFunction = GridKnownFunction.NoFilter;
                    column.CurrentFilterValue = string.Empty;
                }
                rgMamByDiag.MasterTableView.FilterExpression = "";
                rgMamByDiag.Rebind();
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }
    }

    #region Properties used in filters
    protected DateTime? startDate
    {
        set
        {
            ViewState["strD"] = value;
        }
        get
        {
            if (ViewState["strD"] != null)
                return (DateTime)ViewState["strD"];
            else
                return null;
        }
    }
    protected DateTime? endDate
    {
        set
        {
            ViewState["endD"] = value;
        }
        get
        {
            if (ViewState["endD"] != null)
                return (DateTime)ViewState["endD"];
            else
                return null;
        }
    }
    #endregion

    protected void rgMamByDiag_ItemDataBound(object sender, GridItemEventArgs e)
    {
        try
        {
            if (e.Item is GridHeaderItem)
            {
                //add access keys to header items for 508
                GridHeaderItem hi = (GridHeaderItem)e.Item;

                //LinkButton pn = (LinkButton)hi["OrderingPhysician"].Controls[0];
                //pn.AccessKey = "p";

                //LinkButton ln = (LinkButton)hi["PatientLastName"].Controls[0];
                //ln.AccessKey = "n";

                //LinkButton fn = (LinkButton)hi["PatientFirstName"].Controls[0];
                //fn.AccessKey = "f";

                //LinkButton ssn = (LinkButton)hi["PatientSSN"].Controls[0];
                //ssn.AccessKey = "u";

                //add tableheader scope for 508
                //TableCell tcFirstName = hi.Cells[7];
                //tcFirstName.Attributes.Add("scope", "col");
            }

            if (e.Item is GridFilteringItem)
            {
                //Add tooltip to SSN column for 508
                //GridFilteringItem filterItem = (GridFilteringItem)e.Item;
                ////have to do this here because can't in custom column on front end
                ////***index may change***
                ////filterItem.Cells[5].ToolTip = "Filter Textbox for SSN";

                ////set tooltips for each filter button for 508
                ////Button btnPN = (Button)filterItem["OrderingPhysician"].Controls[1];
                ////btnPN.ToolTip = "Filter Physician Name";

                //Button btnLN = (Button)filterItem["PatientLastName"].Controls[1];
                //btnLN.ToolTip = "Filter Last Name";

                //Button btnFN = (Button)filterItem["PatientFirstName"].Controls[1];
                //btnFN.ToolTip = "Filter First Name";

                //Button btnSSN = (Button)filterItem["PatientSSN"].Controls[1];
                //btnSSN.ToolTip = "Filter SSN";
            }

            if (e.Item is GridDataItem)
            {
                //add tool tip to edit row image for 508
                GridDataItem item = (GridDataItem)e.Item;
                //add access keys to row items for 508
                item.Attributes.Add("scope", "row");

                string[] fieldNames = {"CPT_Codes","Diagnosis"};
                string reportName = "MBD_";

                if (isExport)
                {
                    string columnName;
                    TableCell ctc;

                    // Inspect link fields and format accordingly for the output report

                    foreach (string columnRoot in fieldNames)
                    {
                        item = (GridDataItem)e.Item;
                        columnName = reportName + columnRoot + "_Report";
                        ctc = item[columnName];
                        Helpers.configureLinkForExport(ctc, columnRoot, reportName, "");
                    }

                    // Format cells
                    foreach (TableCell cell in e.Item.Cells)
                    {
                        cell.Style["mso-number-format"] = @"\@";
                    }
                }
                else // Not exporting, just displaying grid
                {
                    Label lbl;
                    string sData;
                    RadToolTip rtt;

                    // Inspect each link field and create links or appropriate message

                    foreach (string columnRoot in fieldNames)
                    {

                        lbl = (Label)item.FindControl("lbl" + reportName + columnRoot);
                        sData = ((System.Data.DataRowView)e.Item.DataItem)[columnRoot].ToString();
                        rtt = (RadToolTip)item.FindControl("rtt" + reportName + columnRoot);

                        Helpers.setupLink(lbl, sData, rtt, columnRoot, reportName);
                    }
                }
            }
        }
        catch (Exception ex)
        {
            Logging.WriteLogToFile(_userId, ex);
        }

    }

    protected void rgMamByDiag_ItemCreated(object sender, GridItemEventArgs e)
    {
        if (e.Item is GridFilteringItem && isExport)
            e.Item.Visible = false;

        if (e.Item is GridHeaderItem)
        {
            GridHeaderItem header = (GridHeaderItem)e.Item;

            //loops through all headercells, which is different than columns
            foreach (GridTableHeaderCell headerCell in header.Controls)
            {
                ImageButton img = new ImageButton();

                //if the headercell has controls, it is a column, not a columngroup
                if (headerCell.HasControls())
                {
                    //get the actual header text
                    string headerText = ((LiteralControl)headerCell.Controls[0]).Text;

                    //make sure it isn't the edit header
                    if (headerText != "&nbsp;")
                    {
                        try
                        {
                            img = setupImgButton(headerText, headerCell.HeaderID);

                            headerCell.Controls.Add(img);
                        }
                        catch (Exception ex)
                        {
                            Logging.WriteLogToFile(_userId, ex);
                        }

                        //loop through actual radgrid columns and compare to the header cells 
                        foreach (GridColumn col in rgMamByDiag.Columns)
                        {
                            //test to see if there is currently a sort expression and the header cell matches the column
                            if (rgMamByDiag.MasterTableView.SortExpressions.Count != 0
                                && (rgMamByDiag.MasterTableView.SortExpressions[0].FieldName == col.UniqueName ||
                                    rgMamByDiag.MasterTableView.SortExpressions[0].FieldName == col.SortExpression)
                                && headerText == col.HeaderText)
                            {
                                //check to see if the sort order isn't none
                                if (rgMamByDiag.MasterTableView.SortExpressions[0].SortOrder != GridSortOrder.None)
                                {
                                    //if it isn't none, remove the no sort image
                                    try
                                    {
                                        headerCell.Controls.Remove(img);
                                    }
                                    catch (Exception ex)
                                    {
                                        Logging.WriteLogToFile(_userId, ex);
                                    }
                                }
                            }
                        }
                    }
                }
            }
        }
    }

    ImageButton setupImgButton(string headerText, string headerID)
    {
        //create the sort button image
        ImageButton img = new ImageButton();

        img.ID = "Sort_" + headerID;
        img.AlternateText = "Sort " + headerText + " asc/desc";
        img.ImageUrl = "~/images/sort_none.gif";
        img.TabIndex = 25;
        img.ToolTip = img.AlternateText;

        switch (headerText)
        {
            case "PACT Team":
                img.AccessKey = "t";
                break;
            case "Provider Name":
                img.AccessKey = "p";
                break;
            case "Last Name, First":
                img.AccessKey = "n";
                break;
            case "Last 4":
                img.AccessKey = "s";
                break;
            case "Age":
                img.AccessKey = "a";
                break;
            case "Race":
                img.AccessKey = "r";
                break;
            case "Gender":
                img.AccessKey = "g";
                break;
            case "Patient Zip":
                img.AccessKey = "z";
                break;
            //case "Date Performed":  // Mammogram
            //    img.AccessKey = "m";
            //    break;
            case "BI-RADS Code":
                img.AccessKey = "b";
                break;
            case "Provider Location":  
                img.AccessKey = "l";
                break;
            case "Date of Death":
                img.AccessKey = "k";
                break;
            case "CPT Codes":
                img.AccessKey = "c";
                break;
            case "ICD 9/10":
                img.AccessKey = "h";
                break;

            case "Ordered":
                img.AccessKey = "o";
                break;
            case "Scheduled":
                img.AccessKey = "u";
                break;
            case "Completed":
                img.AccessKey = "m";
                break;

            default:
                break;           
        }

        return img;
    }
    #endregion

    #region Export

    protected void btnExport_Click(object sender, EventArgs e)
    {
        isExport = true;
        ConfigureExport();

        switch (((Button)sender).CommandName)
        {
            case "XLS":
                rgMamByDiag.MasterTableView.ExportToExcel();
                break;
            case "CSV":
                rgMamByDiag.MasterTableView.ExportToCSV();
                break;
            case "PDF":
                rgMamByDiag.MasterTableView.ExportToPdf();
                break;
            case "DOC":
                rgMamByDiag.MasterTableView.ExportToWord();
                break;
        }
    }

    protected void rgMamByDiag_ExcelMLExportRowCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowCreatedArgs e)
    {
        if (e.RowType == Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLRowType.DataRow)
        {
            if (e.Row.Cells[0] != null && ((string)e.Row.Cells[0].Data.DataItem).Contains("U"))
            {
                e.Row.Cells[0].StyleValue = "MyCustomStyle";
            }
        }
    }

    protected void rgMamByDiag_ExcelMLExportStylesCreated(object source, Telerik.Web.UI.GridExcelBuilder.GridExportExcelMLStyleCreatedArgs e)
    {
        foreach (Telerik.Web.UI.GridExcelBuilder.StyleElement style in e.Styles)
        {
            if (style.Id == "headerStyle")
            {
                style.FontStyle.Bold = true;
                style.FontStyle.Color = System.Drawing.Color.Gainsboro;
                style.InteriorStyle.Color = System.Drawing.Color.Wheat;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "itemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.WhiteSmoke;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
            else if (style.Id == "alternatingItemStyle")
            {
                style.InteriorStyle.Color = System.Drawing.Color.LightGray;
                style.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
            }
        }

        Telerik.Web.UI.GridExcelBuilder.StyleElement myStyle = new Telerik.Web.UI.GridExcelBuilder.StyleElement("MyCustomStyle");
        myStyle.FontStyle.Bold = true;
        myStyle.FontStyle.Italic = true;
        myStyle.InteriorStyle.Color = System.Drawing.Color.Gray;
        myStyle.InteriorStyle.Pattern = Telerik.Web.UI.GridExcelBuilder.InteriorPatternType.Solid;
        e.Styles.Add(myStyle);
    }

    public void ConfigureExport()
    {
        rgMamByDiag.ExportSettings.ExportOnlyData = true;
        rgMamByDiag.ExportSettings.IgnorePaging = true;
        rgMamByDiag.ExportSettings.OpenInNewWindow = true;
        rgMamByDiag.ExportSettings.HideStructureColumns = true;

        rgMamByDiag.ExportSettings.Pdf.PageHeight = Unit.Parse("210mm");
        rgMamByDiag.ExportSettings.Pdf.PageWidth = Unit.Parse("400mm");

        foreach (GridColumn col in rgMamByDiag.MasterTableView.RenderColumns)
        {
            if (col.UniqueName.EndsWith("Report"))
                col.Visible = true;
            else if (col.UniqueName.EndsWith("GUI") || col.UniqueName == "EditCommandColumn")
                col.Visible = false;
        }

        rgMamByDiag.Rebind();
    }
    #endregion


    #region GUI Overides
    //these need to be added to MenuBuilder.cs BuildDynamicNavigationItems method
    public override string TopMenuName()
    {
        return "Reporting";
    }

    public override string MenuItemName()
    {
        return "BCCCR Ordered Pending Report";
    }

    public override string AppObjectCode()
    {
        return "BCR_STANDARD_REPORTS";
    }
    #endregion



}